CockpitAccessibilityEntry class final

Constructors

CockpitAccessibilityEntry({required int nodeId, String? label, String? identifier, String? value, String? hint, String? tooltip})
Creates a CockpitAccessibilityEntry.
const
CockpitAccessibilityEntry.fromJson(Map<String, Object?> json)
Decodes a CockpitAccessibilityEntry from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
hasMeaningfulSignal bool
no setter
hint String?
final
identifier String?
final
label String?
final
nodeId int
final
primarySignal String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String?
final
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitAccessibilityEntry as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override