CockpitAccessibilitySummary class final

Constructors

CockpitAccessibilitySummary({required int totalAccessibleTargetCount, required List<CockpitAccessibilityEntry> traversalEntries, required bool truncated})
Creates a CockpitAccessibilitySummary.
CockpitAccessibilitySummary.fromJson(Map<String, Object?> json)
Decodes a CockpitAccessibilitySummary from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAccessibleTargetCount int
final
traversalEntries List<CockpitAccessibilityEntry>
final
truncated bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitAccessibilitySummary as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override