CockpitActionCapability enum
Values
- launchApp → const CockpitActionCapability
- stopApp → const CockpitActionCapability
- focusApp → const CockpitActionCapability
- openDeepLink → const CockpitActionCapability
- grantPermission → const CockpitActionCapability
- dismissPermissionDialog → const CockpitActionCapability
- tap → const CockpitActionCapability
- longPress → const CockpitActionCapability
- doubleTap → const CockpitActionCapability
- scroll → const CockpitActionCapability
- typeText → const CockpitActionCapability
- pressBack → const CockpitActionCapability
- pressHome → const CockpitActionCapability
- openNotifications → const CockpitActionCapability
- captureScreenshot → const CockpitActionCapability
- startRecording → const CockpitActionCapability
- stopRecording → const CockpitActionCapability
- readLogs → const CockpitActionCapability
- collectCrashInfo → const CockpitActionCapability
- pushFile → const CockpitActionCapability
- pullFile → const CockpitActionCapability
- runShell → const CockpitActionCapability
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json) → CockpitActionCapability
Constants
-
values
→ const List<
CockpitActionCapability> - A constant List of the values in this enum, in order of their declaration.