CockpitApiErrorResponse class final

Constructors

CockpitApiErrorResponse({String schemaVersion = 'cockpit.foundation/v2', required String requestId, required DateTime timestamp, required CockpitFailure failure})
Creates a CockpitApiErrorResponse.
CockpitApiErrorResponse.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitApiErrorResponse from a JSON object.
factory

Properties

failure CockpitFailure
final
hashCode int
The hash code for this object.
no setterinherited
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitApiErrorResponse as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited