CockpitApiVersion class final

Implemented types

Constructors

CockpitApiVersion({required int major, required int minor})
Creates a CockpitApiVersion.
CockpitApiVersion.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitApiVersion from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
major int
final
minor int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(CockpitApiVersion other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitApiVersion as a JSON object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override