CockpitApiWarning class final

Constructors

CockpitApiWarning({required CockpitWarningStage stage, required CockpitApiError error})
Creates a CockpitApiWarning.
CockpitApiWarning.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitApiWarning from a JSON object.
factory

Properties

error CockpitApiError
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage CockpitWarningStage
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitApiWarning as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited