CockpitArtifactReference class final

Constructors

CockpitArtifactReference({required String artifactId, required String runId, String? sha256})
Creates a CockpitArtifactReference.
CockpitArtifactReference.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitArtifactReference from a JSON object.
factory

Properties

artifactId String
final
hashCode int
The hash code for this object.
no setterinherited
runId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitArtifactReference as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited