CockpitBundleSummaryAssembler class final

Constructors

CockpitBundleSummaryAssembler({CockpitTimestampProvider? now})
Creates a CockpitBundleSummaryAssembler.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assemble({required CockpitSession session, required CockpitEnvironment environment, required List<CockpitStepRecord> steps, required CockpitTaskStatus status, required List<String> capabilitiesUsed, String? failureSummary}) CockpitContextBundle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited