CockpitCaptureFallbackException class final

Implemented types

Constructors

CockpitCaptureFallbackException({required Object primaryError, required StackTrace primaryStackTrace, required Object fallbackError, required StackTrace fallbackStackTrace})
const

Properties

fallbackError Object
final
fallbackStackTrace StackTrace
final
hashCode int
The hash code for this object.
no setterinherited
primaryError Object
final
primaryStackTrace StackTrace
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited