CockpitCapturedScreenshot class final

Constructors

CockpitCapturedScreenshot({required CockpitArtifactRef artifact, required Uint8List bytes, CockpitSnapshot? snapshot})
Creates a CockpitCapturedScreenshot.
const

Properties

artifact CockpitArtifactRef
final
bytes Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot CockpitSnapshot?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited