CockpitCaseIndexEntry class final
Constructors
- CockpitCaseIndexEntry({required String caseId, String? documentId, String? relativePath, String? title, CockpitTestSourceLocation? location})
- Creates a CockpitCaseIndexEntry.
- CockpitCaseIndexEntry.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
-
Decodes a CockpitCaseIndexEntry from a JSON object.
factory
Properties
- caseId → String
-
final
- documentId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → CockpitTestSourceLocation?
-
final
- relativePath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitCaseIndexEntry as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited