CockpitCaseSubmissionSource class sealed

Inheritance

Properties

documentId String
no setterinherited
documentKind CockpitRunDocumentKind
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
kind String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceSha256 String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitCaseSubmissionSource as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? value, {String path = r'$'}) CockpitCaseSubmissionSource
override