CockpitCommandError class final

Constructors

CockpitCommandError({required String code, required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError.
CockpitCommandError.ambiguousTarget({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor ambiguousTarget.
factory
CockpitCommandError.assertionFailed({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor assertionFailed.
factory
CockpitCommandError.captureFailed({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor captureFailed.
factory
CockpitCommandError.fromJson(Map<String, Object?> json)
Decodes a CockpitCommandError from a JSON object.
factory
CockpitCommandError.gestureExecutionFailed({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor gestureExecutionFailed.
factory
CockpitCommandError.invalidGestureParameters({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor invalidGestureParameters.
factory
CockpitCommandError.targetNotFound({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor targetNotFound.
factory
CockpitCommandError.targetNotHittable({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor targetNotHittable.
factory
CockpitCommandError.timeout({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor timeout.
factory
CockpitCommandError.unsupportedCapability({required String message, Map<String, Object?> details = const <String, Object?>{}})
Creates a CockpitCommandError using the named constructor unsupportedCapability.
factory

Properties

code String
final
details Map<String, Object?>
final
hashCode int
The hash code for this object.
no setteroverride
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitCommandError as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override