CockpitCommandResult class final

Constructors

CockpitCommandResult({required bool success, required String commandId, required CockpitCommandType commandType, CockpitLocatorResolution? locatorResolution, required int durationMs, List<CockpitArtifactRef> artifacts = const <CockpitArtifactRef>[], Map<String, Object?>? snapshot, CockpitCaptureProfile? requestedCaptureProfile, CockpitCaptureKind? resolvedCaptureKind, bool usedCaptureFallback = false, String? degradationReason, bool? changed, CockpitCommandError? error})
Creates a CockpitCommandResult.
CockpitCommandResult.fromJson(Map<String, Object?> json)
Decodes a CockpitCommandResult from a JSON object.
factory

Properties

artifacts List<CockpitArtifactRef>
final
changed bool?
final
commandId String
final
commandType CockpitCommandType
final
degradationReason String?
final
durationMs int
final
error CockpitCommandError?
final
hashCode int
The hash code for this object.
no setteroverride
locatorResolution CockpitLocatorResolution?
final
requestedCaptureProfile CockpitCaptureProfile?
final
resolvedCaptureKind CockpitCaptureKind?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot Map<String, Object?>?
final
success bool
final
usedCaptureFallback bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitCommandResult as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override