CockpitCommandType enum
Values
- tap → const CockpitCommandType
- enterText → const CockpitCommandType
- focusTextInput → const CockpitCommandType
- setTextEditingValue → const CockpitCommandType
- sendTextInputAction → const CockpitCommandType
- sendKeyEvent → const CockpitCommandType
- sendKeyDownEvent → const CockpitCommandType
- sendKeyUpEvent → const CockpitCommandType
- longPress → const CockpitCommandType
- doubleTap → const CockpitCommandType
- drag → const CockpitCommandType
- fling → const CockpitCommandType
- swipe → const CockpitCommandType
- pinchZoom → const CockpitCommandType
- rotate → const CockpitCommandType
- panZoom → const CockpitCommandType
- multiTouch → const CockpitCommandType
- scrollUntilVisible → const CockpitCommandType
- clearNetworkActivity → const CockpitCommandType
- waitForNetworkIdle → const CockpitCommandType
- waitForUiIdle → const CockpitCommandType
- back → const CockpitCommandType
- showOnScreen → const CockpitCommandType
- increase → const CockpitCommandType
- decrease → const CockpitCommandType
- dismiss → const CockpitCommandType
- dismissKeyboard → const CockpitCommandType
- waitFor → const CockpitCommandType
- assertVisible → const CockpitCommandType
- assertText → const CockpitCommandType
- captureScreenshot → const CockpitCommandType
- collectSnapshot → const CockpitCommandType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json) → CockpitCommandType
Constants
-
values
→ const List<
CockpitCommandType> - A constant List of the values in this enum, in order of their declaration.