CockpitContextBundle class final

Constructors

CockpitContextBundle({required CockpitRunManifest manifest, required CockpitEnvironment environment, List<CockpitStepRecord> steps = const [], List<CockpitObservation> observations = const [], required String acceptanceMarkdown, required Map<String, Object?> handoff, Map<String, Object?> delivery = const <String, Object?>{}})
Creates a CockpitContextBundle.
CockpitContextBundle.fromJson(Map<String, Object?> json)
Decodes a CockpitContextBundle from a JSON object.
factory

Properties

acceptanceMarkdown String
final
delivery Map<String, Object?>
final
environment CockpitEnvironment
final
handoff Map<String, Object?>
final
hashCode int
The hash code for this object.
no setteroverride
manifest CockpitRunManifest
final
observations List<CockpitObservation>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<CockpitStepRecord>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitContextBundle as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override