CockpitControlState class final

Runtime state exposed by a Flutter control without application wiring.

Constructors

CockpitControlState({bool enabled = true, bool? selected, CockpitCheckState? checked, bool focused = false, bool readOnly = false, bool obscured = false, Object? value})
const
CockpitControlState.fromJson(Map<String, Object?> json)
factory

Properties

checked CockpitCheckState?
final
enabled bool
final
focused bool
final
hashCode int
The hash code for this object.
no setteroverride
obscured bool
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
final
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override