CockpitCpuFunction class final

Constructors

CockpitCpuFunction({required String name, required int inclusiveTicks, required int exclusiveTicks, String? kind, String? uri, int? line, int? column})
const
CockpitCpuFunction.fromJson(Object? value)
factory

Properties

column int?
final
exclusiveTicks int
final
hashCode int
The hash code for this object.
no setterinherited
inclusiveTicks int
final
kind String?
final
line int?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited