CockpitCpuProfile class final

Constructors

CockpitCpuProfile({required int samplePeriodUs, required int maxStackDepth, required int sampleCount, required int timeOriginUs, required int timeExtentUs, required List<CockpitCpuFunction> functions, required List<CockpitCpuSample> samples, int? pid, int droppedSamples = 0})
CockpitCpuProfile.fromJson(Object? value)
factory

Properties

droppedSamples int
final
functions List<CockpitCpuFunction>
final
hashCode int
The hash code for this object.
no setterinherited
maxStackDepth int
final
pid int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleCount int
final
samplePeriodUs int
final
samples List<CockpitCpuSample>
final
timeExtentUs int
final
timeOriginUs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool includeRaw = true}) Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited