CockpitCpuSample class final

Constructors

CockpitCpuSample({required int timestampUs, required List<int> stack, int? threadId, String? vmTag, String? userTag, bool truncated = false})
const
CockpitCpuSample.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack List<int>
final
threadId int?
final
timestampUs int
final
truncated bool
final
userTag String?
final
vmTag String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited