CockpitDecodePolicy class final

Constructors

CockpitDecodePolicy.negotiatedResponse(Iterable<String> featureIds)
Creates a CockpitDecodePolicy using the named constructor negotiatedResponse.
factory

Properties

allowUnknownEnumValues bool
final
allowUnknownFields bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited