CockpitDiagnosticProperty class final
Constructors
- CockpitDiagnosticProperty({required String name, required String value, required CockpitDiagnosticCategory category})
-
const
-
CockpitDiagnosticProperty.fromJson(Map<
String, Object?> json) -
factory
Properties
- category → CockpitDiagnosticCategory
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override