CockpitDocumentValidationResult class final

Constructors

CockpitDocumentValidationResult({required bool valid, required String sourceSha256, CockpitTestDocument? document, Iterable<CockpitTestDiagnostic> diagnostics = const <CockpitTestDiagnostic>[], Iterable<CockpitTestSourceMapEntry> sourceMap = const <CockpitTestSourceMapEntry>[]})
Creates a CockpitDocumentValidationResult.
CockpitDocumentValidationResult.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitDocumentValidationResult from a JSON object.
factory

Properties

diagnostics List<CockpitTestDiagnostic>
final
document CockpitTestDocument?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceMap List<CockpitTestSourceMapEntry>
final
sourceSha256 String
final
valid bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitDocumentValidationResult as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited