CockpitEnvironment class final

Constructors

CockpitEnvironment({required String platform, required String flutterVersion, required String dartVersion})
Creates a CockpitEnvironment.
const
CockpitEnvironment.fromJson(Map<String, Object?> json)
Decodes a CockpitEnvironment from a JSON object.
factory

Properties

dartVersion String
final
flutterVersion String
final
hashCode int
The hash code for this object.
no setteroverride
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitEnvironment as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override