Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- applicationFailed → const String
- assertionFailed → const String
- authenticationRequired → const String
- cancelled → const String
- conflict → const String
- evidenceFailed → const String
- internalError → const String
- interrupted → const String
- invalidRequest → const String
- locatorNotFound → const String
- notFound → const String
- resourceBusy → const String
- staleReference → const String
- transportFailed → const String
- unsupportedOperation → const String
- upgradeRequired → const String