CockpitEventReplayBoundary class final

Constructors

CockpitEventReplayBoundary({required int requestedAfterSequence, required int earliestAvailableSequence, required int latestAvailableSequence})
Creates a CockpitEventReplayBoundary.
CockpitEventReplayBoundary.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitEventReplayBoundary from a JSON object.
factory

Properties

earliestAvailableSequence int
final
hasGap bool
no setter
hashCode int
The hash code for this object.
no setterinherited
latestAvailableSequence int
final
requestedAfterSequence int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitEventReplayBoundary as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited