CockpitEvidenceCapability enum
Values
- flutterScreenshot → const CockpitEvidenceCapability
- nativeScreenshot → const CockpitEvidenceCapability
- windowCapture → const CockpitEvidenceCapability
- screenRecording → const CockpitEvidenceCapability
- appLogs → const CockpitEvidenceCapability
- deviceLogs → const CockpitEvidenceCapability
- runtimeErrors → const CockpitEvidenceCapability
- crashReports → const CockpitEvidenceCapability
- networkSignals → const CockpitEvidenceCapability
- domSnapshot → const CockpitEvidenceCapability
- windowTree → const CockpitEvidenceCapability
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json) → CockpitEvidenceCapability
Constants
-
values
→ const List<
CockpitEvidenceCapability> - A constant List of the values in this enum, in order of their declaration.