CockpitFailure class final

Constructors

CockpitFailure({required CockpitApiError primary, Iterable<CockpitApiWarning> warnings = const <CockpitApiWarning>[]})
Creates a CockpitFailure.
CockpitFailure.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitFailure from a JSON object.
factory

Properties

artifacts List<CockpitArtifactReference>
latefinal
hashCode int
The hash code for this object.
no setterinherited
primary CockpitApiError
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<CockpitApiWarning>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitFailure as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited