CockpitFeatureDescriptor class final

Constructors

CockpitFeatureDescriptor({required String id, required int revision, required int minimumApiMinor})
Creates a CockpitFeatureDescriptor.
CockpitFeatureDescriptor.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitFeatureDescriptor from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
minimumApiMinor int
final
revision int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitFeatureDescriptor as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited