CockpitHeapClass class final

Constructors

CockpitHeapClass({required String name, required int currentBytes, required int currentInstances, required int accumulatedBytes, required int accumulatedInstances, String? id, String? library})
const
CockpitHeapClass.fromJson(Object? value)
factory

Properties

accumulatedBytes int
final
accumulatedInstances int
final
currentBytes int
final
currentInstances int
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
library String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited