CockpitHeapProfile class final

Constructors

CockpitHeapProfile({required CockpitHeapPoint before, required CockpitHeapPoint after, required Iterable<CockpitHeapClass> classes, int droppedClasses = 0, int intervalMs = 0, Iterable<CockpitHeapSample> samples = const <CockpitHeapSample>[], int droppedSamples = 0, CockpitHeapPoint? groupBefore, CockpitHeapPoint? groupAfter, int? accumulatorResetAt, int? serviceGcAt})
CockpitHeapProfile.fromJson(Object? value)
factory

Properties

accumulatorResetAt int?
VM timestamp of the last allocation accumulator reset, when reported. The value is kept in the VM's native timestamp unit and is not converted to wall-clock time.
final
after CockpitHeapPoint
final
before CockpitHeapPoint
final
classes List<CockpitHeapClass>
final
droppedClasses int
final
droppedSamples int
final
groupAfter CockpitHeapPoint?
final
groupBefore CockpitHeapPoint?
final
hashCode int
The hash code for this object.
no setterinherited
intervalMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samples List<CockpitHeapSample>
final
serviceGcAt int?
VM timestamp of the last service-triggered GC, when reported. The value is kept in the VM's native timestamp unit and is not converted to wall-clock time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited