CockpitHeapSample class final
One VM heap usage sample captured during a performance interval.
Constructors
- CockpitHeapSample({required int timestampUs, required int usageBytes, required int capacityBytes, required int externalBytes})
-
const
- CockpitHeapSample.fromJson(Object? value)
-
factory
Properties
- capacityBytes → int
-
final
- externalBytes → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestampUs → int
-
final
- usageBytes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited