CockpitHttpNetworkObserverConfiguration class final
Constructors
- CockpitHttpNetworkObserverConfiguration({int maxRetainedEntries = 200, int maxHeaderCount = 24, int maxHeaderValueLength = 256, int maxBodyBytes = 4096, bool captureHeaders = true, bool captureBodies = true, bool redact = true, int maxWebSocketFrames = 24, int maxWebSocketPreviewBytes = 1024})
-
Creates a CockpitHttpNetworkObserverConfiguration.
const
Properties
- captureBodies → bool
-
final
- captureHeaders → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxBodyBytes → int
-
final
- maxHeaderCount → int
-
final
- maxHeaderValueLength → int
-
final
- maxRetainedEntries → int
-
final
- maxWebSocketFrames → int
-
final
- maxWebSocketPreviewBytes → int
-
final
- redact → bool
-
Removes credential values from captured diagnostics by default.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override