redact property
Removes credential values from captured diagnostics by default.
Set this to false only in a development-only entrypoint when the raw request and response values are required for local diagnosis.
Implementation
final bool redact;
Removes credential values from captured diagnostics by default.
Set this to false only in a development-only entrypoint when the raw request and response values are required for local diagnosis.
final bool redact;