CockpitIdempotencyKey class final

Constructors

CockpitIdempotencyKey(String value)
Creates a CockpitIdempotencyKey.
CockpitIdempotencyKey.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitIdempotencyKey from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Encodes this CockpitIdempotencyKey as a JSON object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override