CockpitIndexedCaseReference class final

Constructors

CockpitIndexedCaseReference({required String documentId, required String caseId, required String documentSha256})
Creates a CockpitIndexedCaseReference.
CockpitIndexedCaseReference.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitIndexedCaseReference from a JSON object.
factory

Properties

caseId String
final
documentId String
final
documentSha256 String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitIndexedCaseReference as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited