CockpitIndexedSuiteReference class final

Constructors

CockpitIndexedSuiteReference({required String documentId, required String suiteId, required String documentSha256})
Creates a CockpitIndexedSuiteReference.
CockpitIndexedSuiteReference.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitIndexedSuiteReference from a JSON object.
factory

Properties

documentId String
final
documentSha256 String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suiteId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitIndexedSuiteReference as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited