CockpitIndexedSuiteSource class final

Inheritance

Constructors

CockpitIndexedSuiteSource({required CockpitIndexedSuiteReference reference})
Creates a CockpitIndexedSuiteSource.
CockpitIndexedSuiteSource.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitIndexedSuiteSource from a JSON object.
factory

Properties

documentId String
no setteroverride
documentKind CockpitRunDocumentKind
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
kind String
no setteroverride
reference CockpitIndexedSuiteReference
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceSha256 String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitIndexedSuiteSource as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited