CockpitInlineCaseSource class final
- Inheritance
-
- Object
- CockpitRunSubmissionSource
- CockpitCaseSubmissionSource
- CockpitInlineCaseSource
Constructors
- CockpitInlineCaseSource({required CockpitTestCase testCase, required String sourceSha256})
- Creates a CockpitInlineCaseSource.
- CockpitInlineCaseSource.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitInlineCaseSource from a JSON object.
factory
Properties
- documentId → String
-
no setteroverride
- documentKind → CockpitRunDocumentKind
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceSha256 → String
-
final
- testCase → CockpitTestCase
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Encodes this CockpitInlineCaseSource as a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited