CockpitIsolateEvent class final

One lifecycle notification observed on the VM Isolate stream.

Constructors

CockpitIsolateEvent({required String kind, int? timestampMs, String? isolateId, String? name, String? groupId, String? extensionRpc})
const
CockpitIsolateEvent.fromJson(Object? value)
factory

Properties

extensionRpc String?
final
groupId String?
final
hashCode int
The hash code for this object.
no setterinherited
isolateId String?
final
kind String
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampMs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited