CockpitIsolateProfile class final

Before/after isolate state captured around one performance interval.

Constructors

CockpitIsolateProfile({CockpitIsolateStats? before, CockpitIsolateStats? after, Iterable<CockpitIsolateStats> beforeAll = const <CockpitIsolateStats>[], Iterable<CockpitIsolateStats> afterAll = const <CockpitIsolateStats>[], int droppedBefore = 0, int droppedAfter = 0, Iterable<CockpitIsolateEvent> events = const <CockpitIsolateEvent>[], int droppedEvents = 0})
CockpitIsolateProfile.fromJson(Object? value)
factory

Properties

after CockpitIsolateStats?
final
afterAll List<CockpitIsolateStats>
final
before CockpitIsolateStats?
final
beforeAll List<CockpitIsolateStats>
final
droppedAfter int
final
droppedBefore int
final
droppedEvents int
final
events List<CockpitIsolateEvent>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited