CockpitIsolateStats class final

A bounded snapshot of one Dart isolate's runtime health.

Constructors

CockpitIsolateStats({required String id, required String name, String? number, String? groupId, bool? runnable, int? livePorts, int? libraryCount, int? extensionCount, List<String> extensionRpcs = const <String>[], int? startTimeMs, bool? system, String? pauseKind, int? pauseTimestampMs, bool? pauseAsync, String? error, bool? pauseOnExit, String? exceptionPauseMode, String? rootLibUri, int? breakpointCount, CockpitHeapPoint? newHeap, CockpitHeapPoint? oldHeap})
const
CockpitIsolateStats.fromJson(Object? value)
factory

Properties

breakpointCount int?
final
error String?
final
exceptionPauseMode String?
final
extensionCount int?
final
extensionRpcs List<String>
final
groupId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
libraryCount int?
final
livePorts int?
final
name String
final
newHeap CockpitHeapPoint?
final
number String?
final
oldHeap CockpitHeapPoint?
final
pauseAsync bool?
final
pauseKind String?
final
pauseOnExit bool?
final
pauseTimestampMs int?
final
rootLibUri String?
final
runnable bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimeMs int?
final
system bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited