CockpitLocatorResolution class final
Constructors
-
CockpitLocatorResolution({required CockpitLocatorKind matchedKind, required String matchedValue, Map<
String, String> matchedSignals = const <String, String>{}}) -
Creates a CockpitLocatorResolution.
const
-
CockpitLocatorResolution.fromJson(Map<
String, Object?> json) -
Decodes a CockpitLocatorResolution from a JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- matchedKind → CockpitLocatorKind
-
final
-
matchedSignals
→ Map<
String, String> -
final
- matchedValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitLocatorResolution as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override