CockpitMultiTouchStep class final

Constructors

CockpitMultiTouchStep({required int pointer, required CockpitMultiTouchPhase phase, required int atMs, required double dx, required double dy})
Creates a CockpitMultiTouchStep.
const
CockpitMultiTouchStep.fromJson(Map<String, Object?> json)
Decodes a CockpitMultiTouchStep from a JSON object.
factory

Properties

atMs int
final
dx double
final
dy double
final
hashCode int
The hash code for this object.
no setteroverride
phase CockpitMultiTouchPhase
final
pointer int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitMultiTouchStep as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override