CockpitNegotiationRequest class final

Constructors

CockpitNegotiationRequest({required CockpitApiVersion apiVersion, Iterable<String> requiredFeatures = const <String>[]})
Creates a CockpitNegotiationRequest.
CockpitNegotiationRequest.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitNegotiationRequest from a JSON object.
factory

Properties

apiVersion CockpitApiVersion
final
hashCode int
The hash code for this object.
no setterinherited
requiredFeatures List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitNegotiationRequest as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited