CockpitNegotiationResult class final

Constructors

CockpitNegotiationResult({required CockpitApiVersion apiVersion, Iterable<String> featureIds = const <String>[]})
Creates a CockpitNegotiationResult.
CockpitNegotiationResult.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitNegotiationResult from a JSON object.
factory

Properties

apiVersion CockpitApiVersion
final
featureIds List<String>
final
hashCode int
The hash code for this object.
no setterinherited
responseDecodePolicy CockpitDecodePolicy
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitNegotiationResult as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited