CockpitNetworkEntry class final

Constructors

CockpitNetworkEntry({required String requestId, required String method, required String uri, required DateTime startedAt, required int durationMs, CockpitNetworkProtocol protocol = CockpitNetworkProtocol.http, CockpitNetworkState state = CockpitNetworkState.complete, DateTime? updatedAt, int? statusCode, Map<String, String> requestHeaders = const <String, String>{}, Map<String, String> responseHeaders = const <String, String>{}, String? requestBodyPreview, String? responseBodyPreview, int requestBodyBytes = 0, int responseBodyBytes = 0, bool requestBodyTruncated = false, bool responseBodyTruncated = false, CockpitWebSocketActivity? webSocket, String? error})
Creates a CockpitNetworkEntry.
const
CockpitNetworkEntry.fromJson(Map<String, Object?> json)
Decodes a CockpitNetworkEntry from a JSON object.
factory

Properties

durationMs int
final
error String?
final
hashCode int
The hash code for this object.
no setteroverride
isActive bool
no setter
isFailure bool
no setter
method String
final
protocol CockpitNetworkProtocol
final
requestBodyBytes int
final
requestBodyPreview String?
final
requestBodyTruncated bool
final
requestHeaders Map<String, String>
final
requestId String
final
responseBodyBytes int
final
responseBodyPreview String?
final
responseBodyTruncated bool
final
responseHeaders Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final
state CockpitNetworkState
final
statusCode int?
final
updatedAt DateTime?
final
uri String
final
webSocket CockpitWebSocketActivity?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitNetworkEntry as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override