CockpitNetworkObserver class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot({int maxEntries = 10, CockpitNetworkQuery query = const CockpitNetworkQuery()}) CockpitNetworkSnapshot
toString() String
A string representation of this object.
inherited
waitForIdle({Duration quietWindow = const Duration(milliseconds: 150), Duration timeout = const Duration(seconds: 2)}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited