CockpitNetworkQuery class final

Constructors

CockpitNetworkQuery({String? id, String? before, String? method, String? uriContains, bool onlyFailures = false, int? statusCodeAtLeast})
Creates a CockpitNetworkQuery.
const
CockpitNetworkQuery.fromJson(Map<String, Object?> json)
Decodes a CockpitNetworkQuery from a JSON object.
factory

Properties

before String?
final
hashCode int
The hash code for this object.
no setteroverride
id String?
final
isEmpty bool
no setter
method String?
final
onlyFailures bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCodeAtLeast int?
final
uriContains String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitNetworkQuery as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override