CockpitObservation class final

Constructors

CockpitObservation({String? routeName, List<String> interactiveElements = const [], CockpitObservationPhase? phase, CockpitSnapshotProfile? diagnosticLevel, bool truncated = false, CockpitArtifactRef? diagnosticsArtifactRef, CockpitSnapshotSummary? summary, CockpitTargetKind? targetKind, CockpitPlaneKind? executionPlane, CockpitSurfaceKind? surfaceKind, bool fallbackUsed = false})
CockpitObservation.fromJson(Map<String, Object?> json)
factory

Properties

diagnosticLevel CockpitSnapshotProfile?
final
diagnosticsArtifactRef CockpitArtifactRef?
final
executionPlane CockpitPlaneKind?
final
fallbackUsed bool
final
hashCode int
The hash code for this object.
no setteroverride
interactiveElements List<String>
final
phase CockpitObservationPhase?
final
routeName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary CockpitSnapshotSummary?
final
surfaceKind CockpitSurfaceKind?
final
targetKind CockpitTargetKind?
final
truncated bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override