CockpitObservationAssembler class final

Constructors

CockpitObservationAssembler()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executionPlaneFor(CockpitCommandResult result) CockpitPlaneKind
normalizeCommandSnapshot(CockpitCommand command, CockpitCommandResult result, {required int stepIndex}) CockpitSnapshot?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observationFromCommandResult(CockpitCommandResult result, CockpitSnapshot? snapshot) CockpitObservation?
surfaceKindFor(CockpitCommandResult result) CockpitSurfaceKind
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited