CockpitOperationAdmissionProjection class final

Constructors

CockpitOperationAdmissionProjection({required String? rootId, required String? workspaceId, required CockpitIdempotencyKey? idempotencyKey, required Iterable<String> requiredFeatures})
Creates a CockpitOperationAdmissionProjection.
CockpitOperationAdmissionProjection.empty()
Creates a CockpitOperationAdmissionProjection using the named constructor empty.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
idempotencyKey CockpitIdempotencyKey?
final
requiredFeatures List<String>
final
rootId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspaceId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited