CockpitOperationContract<T> class final

Properties

descriptor CockpitOperationDescriptor
final
hashCode int
The hash code for this object.
no setterinherited
requestSchemaRef String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeAdmission(Object? input) CockpitOperationAdmissionProjection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateCatalogRegistration() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited