CockpitOperationDescriptor class final

Constructors

CockpitOperationDescriptor({required String kind, required String title, required String description, required CockpitOperationScope scope, required CockpitMutationClass mutationClass, required CockpitIdempotencyBehavior idempotency, required CockpitOperationExecutionMode executionMode, required int defaultTimeoutMs, required int maximumTimeoutMs, required String requestSchemaRef, required String responseSchemaRef, Iterable<CockpitEnumValue<CockpitSafetyEffect>> safetyEffects = const <CockpitEnumValue<CockpitSafetyEffect>>[], Iterable<String> requiredFeatures = const <String>[]})
Creates a CockpitOperationDescriptor.
CockpitOperationDescriptor.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitOperationDescriptor from a JSON object.
factory

Properties

defaultTimeoutMs int
final
description String
final
executionMode CockpitOperationExecutionMode
final
hashCode int
The hash code for this object.
no setterinherited
idempotency CockpitIdempotencyBehavior
final
kind String
final
maximumTimeoutMs int
final
mutationClass CockpitMutationClass
final
requestSchemaRef String
final
requiredFeatures List<String>
final
responseSchemaRef String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetyEffects List<CockpitEnumValue<CockpitSafetyEffect>>
final
scope CockpitOperationScope
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitOperationDescriptor as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited