CockpitPage<T> class final

Constructors

CockpitPage({required Iterable<T> items, String? nextCursor, int? totalCount})
Creates a CockpitPage.

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<T>
final
nextCursor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object? encodeItem(T item)) Map<String, Object?>
Encodes this CockpitPage as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson<T>(Object? value, T decodeItem(Object? value, String path, CockpitDecodePolicy policy), {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests}) CockpitPage<T>