CockpitPerformanceCaptureSession class final

State returned after a capture window is opened.

Constructors

CockpitPerformanceCaptureSession({required CockpitPerformanceCaptureRequest request, required DateTime startedAt, required String buildMode})
CockpitPerformanceCaptureSession.fromJson(Object? value)
factory

Properties

buildMode String
final
hashCode int
The hash code for this object.
no setterinherited
request CockpitPerformanceCaptureRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited