buildStartUs property
Raw engine phase timestamps. They are optional because synthetic hosts may provide only the aggregate FrameTiming durations.
Implementation
final int? buildStartUs;
Raw engine phase timestamps. They are optional because synthetic hosts may provide only the aggregate FrameTiming durations.
final int? buildStartUs;