CockpitPerformancePhaseSummary class final

Percentile and budget information for one frame phase.

Constructors

CockpitPerformancePhaseSummary({required int sampleCount, required int averageUs, required int p50Us, required int p90Us, required int p99Us, required int worstUs, required int budgetUs, required int missedBudget})
const
CockpitPerformancePhaseSummary.fromJson(Object? value)
factory

Properties

averageUs int
final
budgetUs int
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
missedBudget int
final
p50Us int
final
p90Us int
final
p99Us int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleCount int
Number of retained frames used to calculate this phase summary.
final
worstUs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited