CockpitPerformancePluginOptions class final

Limits and filtering applied to one plugin during a capture.

Constructors

CockpitPerformancePluginOptions({int maxEvents = 10000, int maxPayloadBytes = 64 * 1024, int maxPayloadDepth = 8, Duration sampleEvery = Duration.zero, Set<String> categories = const <String>{}, Duration lifecycleTimeout = const Duration(seconds: 2)})
const

Properties

categories Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
lifecycleTimeout Duration
final
maxEvents int
final
maxPayloadBytes int
final
maxPayloadDepth int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleEvery Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot() CockpitPerformancePluginOptions
Takes an immutable snapshot so a caller cannot mutate capture policy after a plugin has been registered.
toString() String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited