snapshot method

Takes an immutable snapshot so a caller cannot mutate capture policy after a plugin has been registered.

Implementation

CockpitPerformancePluginOptions snapshot() =>
    CockpitPerformancePluginOptions._copy(
      maxEvents: maxEvents,
      maxPayloadBytes: maxPayloadBytes,
      maxPayloadDepth: maxPayloadDepth,
      sampleEvery: sampleEvery,
      lifecycleTimeout: lifecycleTimeout,
      categories: categories,
    );