CockpitPerformancePluginRegistry class final

Registry configured on a development-only FlutterCockpitConfig.

Constructors

CockpitPerformancePluginRegistry({Iterable<CockpitPerformancePlugin> plugins = const <CockpitPerformancePlugin>[]})

Properties

hashCode int
The hash code for this object.
no setterinherited
plugins List<CockpitPerformancePlugin>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture({Iterable<CockpitPerformancePlugin> additional = const <CockpitPerformancePlugin>[], int maxEvents = 200000, String? isolateId, void onEvent(CockpitPerformanceEvent event)?}) CockpitPerformancePluginCapture
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(CockpitPerformancePlugin plugin) → void
remove(String id) bool
replace(Iterable<CockpitPerformancePlugin> plugins) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited