CockpitPerformanceSink class final

Synchronous, bounded event sink exposed to a plugin or AOP adapter.

Properties

enabled bool
no setter
hashCode int
The hash code for this object.
no setterinherited
nowUs int
Returns the VM-compatible monotonic timeline timestamp in microseconds.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

begin(String name, {String category = 'app', Map<String, Object?> args = const <String, Object?>{}, CockpitPerformanceLocation? location}) CockpitPerformanceSpan
counter(String name, num value, {String category = 'app', Map<String, Object?> args = const <String, Object?>{}, CockpitPerformanceLocation? location}) → void
instant(String name, {String category = 'app', Map<String, Object?> args = const <String, Object?>{}, CockpitPerformanceLocation? location}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sample(String name, num value, {String category = 'sample', Map<String, Object?> args = const <String, Object?>{}, CockpitPerformanceLocation? location}) → void
span(String name, {required int startUs, required int endUs, String category = 'app', Map<String, Object?> args = const <String, Object?>{}, CockpitPerformanceLocation? location}) → void
toString() String
A string representation of this object.
inherited
trace<T>(String name, FutureOr<T> action(), {String category = 'app', Map<String, Object?> args = const <String, Object?>{}, CockpitPerformanceLocation? location}) Future<T>

Operators

operator ==(Object other) bool
The equality operator.
inherited