CockpitRebuildTotal class final
Aggregate rebuild counts for one widget source location.
Constructors
- CockpitRebuildTotal({required int locationId, required int count})
- CockpitRebuildTotal.fromJson(Object? value)
-
factory
Properties
- count → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited