CockpitRecordingCapabilities class final

Constructors

CockpitRecordingCapabilities({required bool supportsNativeRecording, CockpitRecordingKind? preferredAcceptanceRecordingKind, List<CockpitRecordingLayer> supportedLayers = const <CockpitRecordingLayer>[], CockpitRecordingLayer? preferredLayer, List<String> recordingLimitations = const <String>[]})
CockpitRecordingCapabilities.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
preferredAcceptanceRecordingKind CockpitRecordingKind?
final
preferredLayer CockpitRecordingLayer?
final
recordingLimitations List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedLayers List<CockpitRecordingLayer>
final
supportsNativeRecording bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override