CockpitRecordingRequest class final

Constructors

CockpitRecordingRequest({required CockpitRecordingPurpose purpose, required String name, CockpitRecordingMode mode = CockpitRecordingMode.auto, CockpitRecordingLayer? layer, bool? allowFallback, bool attachToStep = false, Duration tailStabilizationDelay = const Duration(milliseconds: 1400)})
Creates a CockpitRecordingRequest.
const
CockpitRecordingRequest.fromJson(Map<String, Object?> json)
Decodes a CockpitRecordingRequest from a JSON object.
factory

Properties

allowFallback bool?
final
allowsFallback bool
no setter
attachToStep bool
final
hashCode int
The hash code for this object.
no setteroverride
layer CockpitRecordingLayer?
final
mode CockpitRecordingMode
final
name String
final
purpose CockpitRecordingPurpose
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tailStabilizationDelay Duration
final

Methods

copyWith({CockpitRecordingPurpose? purpose, String? name, CockpitRecordingMode? mode, CockpitRecordingLayer? layer, Object? allowFallback = _unsetField, bool? attachToStep, Duration? tailStabilizationDelay}) CockpitRecordingRequest
Returns a copy of this CockpitRecordingRequest with supplied fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRecordingRequest as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override