CockpitRecordingResult class final

Constructors

CockpitRecordingResult({required CockpitRecordingState state, CockpitRecordingPurpose? purpose, CockpitRecordingKind? recordingKind, CockpitRecordingMode? requestedMode, CockpitRecordingLayer? requestedLayer, CockpitRecordingLayer? effectiveLayer, bool fallbackUsed = false, String? fallbackReason, CockpitArtifactRef? artifact, int? durationMs, List<int>? bytes, String? sourceFilePath, String? failureReason})
Creates a CockpitRecordingResult.
CockpitRecordingResult.fromJson(Map<String, Object?> json)
Decodes a CockpitRecordingResult from a JSON object.
factory

Properties

artifact CockpitArtifactRef?
final
bytes List<int>?
final
durationMs int?
final
effectiveLayer CockpitRecordingLayer?
final
failureReason String?
final
fallbackReason String?
final
fallbackUsed bool
final
hashCode int
The hash code for this object.
no setteroverride
purpose CockpitRecordingPurpose?
final
recordingKind CockpitRecordingKind?
final
requestedLayer CockpitRecordingLayer?
final
requestedMode CockpitRecordingMode?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceFilePath String?
final
state CockpitRecordingState
final

Methods

copyWith({CockpitRecordingState? state, CockpitRecordingPurpose? purpose, CockpitRecordingKind? recordingKind, Object? requestedMode = _unsetField, Object? requestedLayer = _unsetField, Object? effectiveLayer = _unsetField, bool? fallbackUsed, Object? fallbackReason = _unsetField, Object? artifact = _unsetField, Object? durationMs = _unsetField, Object? bytes = _unsetField, Object? sourceFilePath = _unsetField, Object? failureReason = _unsetField}) CockpitRecordingResult
Returns a copy of this CockpitRecordingResult with supplied fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRecordingResult as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override