CockpitRecordingSession class final
Constructors
- CockpitRecordingSession({required CockpitRecordingRequest request, required CockpitRecordingState state})
-
Creates a CockpitRecordingSession.
const
-
CockpitRecordingSession.fromJson(Map<
String, Object?> json) -
Decodes a CockpitRecordingSession from a JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- request → CockpitRecordingRequest
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → CockpitRecordingState
-
final
Methods
-
copyWith(
{CockpitRecordingRequest? request, CockpitRecordingState? state}) → CockpitRecordingSession - Returns a copy of this CockpitRecordingSession with supplied fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRecordingSession as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override