CockpitRemoteArtifactDownload class final

Constructors

CockpitRemoteArtifactDownload({required CockpitArtifactRef artifact, required String downloadPath})
Creates a CockpitRemoteArtifactDownload.
const
CockpitRemoteArtifactDownload.fromJson(Map<String, Object?> json)
Decodes a CockpitRemoteArtifactDownload from a JSON object.
factory

Properties

artifact CockpitArtifactRef
final
downloadPath String
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRemoteArtifactDownload as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override