CockpitRemoteRecordingResponse class final
Constructors
-
CockpitRemoteRecordingResponse({required CockpitRecordingResult result, List<
CockpitRemoteArtifactDownload> artifactDownloads = const <CockpitRemoteArtifactDownload>[]}) - Creates a CockpitRemoteRecordingResponse.
-
CockpitRemoteRecordingResponse.fromJson(Map<
String, Object?> json) -
Decodes a CockpitRemoteRecordingResponse from a JSON object.
factory
Properties
-
artifactDownloads
→ List<
CockpitRemoteArtifactDownload> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- result → CockpitRecordingResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRemoteRecordingResponse as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override