CockpitResourceDescriptor class final

Constructors

CockpitResourceDescriptor({required String kind, required CockpitOperationScope scope, required String uriTemplate, required String mediaType, Iterable<String> requiredFeatures = const <String>[]})
Creates a CockpitResourceDescriptor.
CockpitResourceDescriptor.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitResourceDescriptor from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
final
mediaType String
final
requiredFeatures List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope CockpitOperationScope
final
uriTemplate String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitResourceDescriptor as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited