CockpitRootRemoval class final

Constructors

CockpitRootRemoval({bool force = false, int drainTimeoutMs = 30000})
Creates a CockpitRootRemoval.
CockpitRootRemoval.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitRootRemoval from a JSON object.
factory

Properties

drainTimeoutMs int
final
force bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRootRemoval as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited