CockpitRootResource class final

Constructors

CockpitRootResource({required String rootId, required String canonicalPath, required String filesystemIdentity, required CockpitRootState state, required DateTime registeredAt, required DateTime updatedAt, DateTime? retiredAt})
Creates a CockpitRootResource.
CockpitRootResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitRootResource from a JSON object.
factory

Properties

canonicalPath String
final
filesystemIdentity String
final
hashCode int
The hash code for this object.
no setterinherited
registeredAt DateTime
final
retiredAt DateTime?
final
rootId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CockpitRootState
final
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRootResource as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited