CockpitRunAccepted class final

Constructors

CockpitRunAccepted({required String workspaceId, required String runId, required String statusUrl, required String eventsUrl, required DateTime submittedAt, required bool replayed})
Creates a CockpitRunAccepted.
CockpitRunAccepted.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitRunAccepted from a JSON object.
factory

Properties

eventsUrl String
final
hashCode int
The hash code for this object.
no setterinherited
replayed bool
final
runId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusUrl String
final
submittedAt DateTime
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRunAccepted as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited