CockpitRunCancellationRequest class final

Constructors

CockpitRunCancellationRequest({required CockpitIdempotencyKey idempotencyKey, String? reason})
Creates a CockpitRunCancellationRequest.
CockpitRunCancellationRequest.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitRunCancellationRequest from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
idempotencyKey CockpitIdempotencyKey
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRunCancellationRequest as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited