CockpitRunManifest class final
Constructors
-
CockpitRunManifest({required String sessionId, required String taskId, required String platform, required CockpitTaskStatus status, required DateTime startedAt, DateTime? finishedAt, List<
CockpitArtifactRef> artifactRefs = const [], String? failureSummary, CockpitTargetKind? targetKind, CockpitPlaneKind? primaryExecutionPlane, List<CockpitPlaneKind> planesUsed = const [], List<CockpitSurfaceKind> surfaceKindsUsed = const [], int fallbackCount = 0, List<String> capabilitiesUsed = const [], int commandCount = 0, int screenshotCount = 0, int failureCount = 0, int nativeScreenshotCount = 0, int flutterScreenshotCount = 0, bool deliveryArtifactsReady = false, List<String> deliveryArtifactFailureCodes = const [], int recordingCount = 0, int nativeRecordingCount = 0, bool deliveryVideoReady = false, List<String> deliveryVideoFailureCodes = const [], int runtimeEventCount = 0, int runtimeErrorCount = 0, int runtimeWarningCount = 0}) - Creates a CockpitRunManifest.
-
CockpitRunManifest.fromJson(Map<
String, Object?> json) -
Decodes a CockpitRunManifest from a JSON object.
factory
Properties
-
artifactRefs
→ List<
CockpitArtifactRef> -
final
-
capabilitiesUsed
→ List<
String> -
final
- commandCount → int
-
final
-
deliveryArtifactFailureCodes
→ List<
String> -
final
- deliveryArtifactsReady → bool
-
final
-
deliveryVideoFailureCodes
→ List<
String> -
final
- deliveryVideoReady → bool
-
final
- failureCount → int
-
final
- failureSummary → String?
-
final
- fallbackCount → int
-
final
- finishedAt → DateTime?
-
final
- flutterScreenshotCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- nativeRecordingCount → int
-
final
- nativeScreenshotCount → int
-
final
-
planesUsed
→ List<
CockpitPlaneKind> -
final
- platform → String
-
final
- primaryExecutionPlane → CockpitPlaneKind?
-
final
- recordingCount → int
-
final
- runtimeErrorCount → int
-
final
- runtimeEventCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runtimeWarningCount → int
-
final
- screenshotCount → int
-
final
- sessionId → String
-
final
- startedAt → DateTime
-
final
- status → CockpitTaskStatus
-
final
-
surfaceKindsUsed
→ List<
CockpitSurfaceKind> -
final
- targetKind → CockpitTargetKind?
-
final
- taskId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRunManifest as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override