CockpitRunResource class final

Constructors

CockpitRunResource({required String projectId, required String workspaceId, required String runId, required CockpitRunDocumentKind documentKind, required String documentId, required String sourceSha256, required CockpitRunLifecycle lifecycle, required DateTime submittedAt, CockpitRunOutcome? outcome, CockpitRunStability? stability, DateTime? startedAt, DateTime? finishedAt, Iterable<String> caseIds = const <String>[], Iterable<String> activeAttemptIds = const <String>[], CockpitFailure? failure})
Creates a CockpitRunResource.
CockpitRunResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitRunResource from a JSON object.
factory

Properties

activeAttemptIds List<String>
final
caseIds List<String>
final
documentId String
final
documentKind CockpitRunDocumentKind
final
failure CockpitFailure?
final
finishedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
lifecycle CockpitRunLifecycle
final
outcome CockpitRunOutcome?
final
projectId String
final
runId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceSha256 String
final
stability CockpitRunStability?
final
startedAt DateTime?
final
submittedAt DateTime
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRunResource as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited