CockpitRunSubmissionSource class sealed
Properties
- documentId → String
-
no setter
- documentKind → CockpitRunDocumentKind
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceSha256 → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRunSubmissionSource as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? value, {String path = r'$'}) → CockpitRunSubmissionSource