CockpitRuntimeQuery class final

Constructors

CockpitRuntimeQuery({bool onlyErrors = false, String? messageContains})
Creates a CockpitRuntimeQuery.
const
CockpitRuntimeQuery.fromJson(Map<String, Object?> json)
Decodes a CockpitRuntimeQuery from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
messageContains String?
final
onlyErrors bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRuntimeQuery as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override