CockpitRuntimeSnapshot class final
Constructors
-
CockpitRuntimeSnapshot({required int totalEntryCount, required int errorCount, required int warningCount, required List<
CockpitRuntimeEvent> entries, int capturedEntryCount = 0, CockpitRuntimeQuery query = const CockpitRuntimeQuery(), bool truncated = false}) -
Creates a CockpitRuntimeSnapshot.
const
-
CockpitRuntimeSnapshot.fromJson(Map<
String, Object?> json) -
Decodes a CockpitRuntimeSnapshot from a JSON object.
factory
Properties
- capturedEntryCount → int
-
final
-
entries
→ List<
CockpitRuntimeEvent> -
final
- errorCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- query → CockpitRuntimeQuery
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalEntryCount → int
-
final
- truncated → bool
-
final
- warningCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRuntimeSnapshot as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override