CockpitScreenshotReason enum
Values
- baseline → const CockpitScreenshotReason
-
const CockpitScreenshotReason('baseline') - beforeAction → const CockpitScreenshotReason
-
const CockpitScreenshotReason('before_action') - afterAction → const CockpitScreenshotReason
-
const CockpitScreenshotReason('after_action') - assertionFailure → const CockpitScreenshotReason
-
const CockpitScreenshotReason('assertion_failure') - acceptance → const CockpitScreenshotReason
-
const CockpitScreenshotReason('acceptance')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- jsonValue → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json) → CockpitScreenshotReason
Constants
-
values
→ const List<
CockpitScreenshotReason> - A constant List of the values in this enum, in order of their declaration.