CockpitServerInfo class final

Constructors

CockpitServerInfo({String schemaVersion = 'cockpit.foundation/v2', required String instanceId, required CockpitApiVersion apiVersion, required String engineVersion, required DateTime startedAt, Iterable<CockpitFeatureDescriptor> features = const <CockpitFeatureDescriptor>[]})
Creates a CockpitServerInfo.
CockpitServerInfo.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitServerInfo from a JSON object.
factory

Properties

apiVersion CockpitApiVersion
final
engineVersion String
final
featureIds Set<String>
no setter
features List<CockpitFeatureDescriptor>
final
hashCode int
The hash code for this object.
no setterinherited
instanceId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
startedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitServerInfo as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited