CockpitSnapshot class final

Constructors

CockpitSnapshot({required String? routeName, List<CockpitSnapshotTarget> visibleTargets = const <CockpitSnapshotTarget>[], CockpitSnapshotProfile diagnosticLevel = CockpitSnapshotProfile.live, bool truncated = false, CockpitArtifactRef? diagnosticsArtifactRef, CockpitArtifactRef? treeArtifactRef, CockpitSnapshotSummary? summary, CockpitNetworkSnapshot? network, CockpitRuntimeSnapshot? runtime, CockpitRebuildSnapshot? rebuild, CockpitAccessibilitySummary? accessibility, CockpitFocusSnapshot? focus, CockpitWidgetTree? tree})
Creates a CockpitSnapshot.
CockpitSnapshot.fromJson(Map<String, Object?> json)
Decodes a CockpitSnapshot from a JSON object.
factory

Properties

accessibility CockpitAccessibilitySummary?
final
diagnosticLevel CockpitSnapshotProfile
final
diagnosticsArtifactRef CockpitArtifactRef?
final
focus CockpitFocusSnapshot?
final
hashCode int
The hash code for this object.
no setteroverride
network CockpitNetworkSnapshot?
final
rebuild CockpitRebuildSnapshot?
final
routeName String?
final
runtime CockpitRuntimeSnapshot?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary CockpitSnapshotSummary?
final
tree CockpitWidgetTree?
final
treeArtifactRef CockpitArtifactRef?
final
truncated bool
final
visibleTargets List<CockpitSnapshotTarget>
final

Methods

copyWith({String? routeName, List<CockpitSnapshotTarget>? visibleTargets, CockpitSnapshotProfile? diagnosticLevel, bool? truncated, CockpitArtifactRef? diagnosticsArtifactRef, CockpitArtifactRef? treeArtifactRef, CockpitSnapshotSummary? summary, CockpitNetworkSnapshot? network, CockpitRuntimeSnapshot? runtime, CockpitRebuildSnapshot? rebuild, CockpitAccessibilitySummary? accessibility, CockpitFocusSnapshot? focus, CockpitWidgetTree? tree}) CockpitSnapshot
Returns a copy of this CockpitSnapshot with supplied fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitSnapshot as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override