CockpitSnapshotAncestor class final

Constructors

CockpitSnapshotAncestor({required String typeName, String? cockpitId, String? semanticId, String? keyValue, String? textPreview, String? tooltip, String? routeName, String? path})
Creates a CockpitSnapshotAncestor.
const
CockpitSnapshotAncestor.fromJson(Map<String, Object?> json)
Decodes a CockpitSnapshotAncestor from a JSON object.
factory

Properties

cockpitId String?
final
hashCode int
The hash code for this object.
no setteroverride
keyValue String?
final
path String?
final
routeName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticId String?
final
textPreview String?
final
tooltip String?
final
typeName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitSnapshotAncestor as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override