CockpitSnapshotLayout class final

Constructors

CockpitSnapshotLayout({required double width, required double height, required double dx, required double dy, String? constraintsSummary})
Creates a CockpitSnapshotLayout.
const
CockpitSnapshotLayout.fromJson(Map<String, Object?> json)
Decodes a CockpitSnapshotLayout from a JSON object.
factory

Properties

constraintsSummary String?
final
dx double
final
dy double
final
hashCode int
The hash code for this object.
no setteroverride
height double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitSnapshotLayout as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override