CockpitSnapshotOptions class final

Constructors

CockpitSnapshotOptions({CockpitSnapshotProfile profile = CockpitSnapshotProfile.live, String? query, int maxTargets = 25, int maxAncestorsPerTarget = 0, int maxPropertiesPerTarget = 0, bool includeStyleDetails = false, bool includeDiagnosticProperties = false, CockpitSnapshotArtifactMode artifact = CockpitSnapshotArtifactMode.inline, bool includeRebuildActivity = false, int maxRebuildEntries = 8, bool includeNetworkActivity = false, int maxNetworkEntries = 8, CockpitNetworkQuery networkQuery = const CockpitNetworkQuery(), bool includeRuntimeActivity = false, int maxRuntimeEntries = 8, CockpitRuntimeQuery runtimeQuery = const CockpitRuntimeQuery(), bool includeAccessibilitySummary = false, int maxAccessibilityEntries = 8, CockpitWidgetTreeOptions? tree})
Creates a CockpitSnapshotOptions.
const
CockpitSnapshotOptions.baseline()
Creates a CockpitSnapshotOptions using the named constructor baseline.
const
CockpitSnapshotOptions.forensic()
Creates a CockpitSnapshotOptions using the named constructor forensic.
const
CockpitSnapshotOptions.fromJson(Map<String, Object?> json)
Decodes a CockpitSnapshotOptions from a JSON object.
factory
CockpitSnapshotOptions.investigate()
Creates a CockpitSnapshotOptions using the named constructor investigate.
const
CockpitSnapshotOptions.live()
Creates a CockpitSnapshotOptions using the named constructor live.
const

Properties

artifact CockpitSnapshotArtifactMode
final
hashCode int
The hash code for this object.
no setteroverride
includeAccessibilitySummary bool
final
includeDiagnosticProperties bool
final
includeNetworkActivity bool
final
includeRebuildActivity bool
final
includeRuntimeActivity bool
final
includeStyleDetails bool
final
maxAccessibilityEntries int
final
maxAncestorsPerTarget int
final
maxNetworkEntries int
final
maxPropertiesPerTarget int
final
maxRebuildEntries int
final
maxRuntimeEntries int
final
maxTargets int
final
networkQuery CockpitNetworkQuery
final
profile CockpitSnapshotProfile
final
query String?
final
runtimeQuery CockpitRuntimeQuery
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tree CockpitWidgetTreeOptions?
final

Methods

copyWith({CockpitSnapshotProfile? profile, String? query, bool clearQuery = false, int? maxTargets, int? maxAncestorsPerTarget, int? maxPropertiesPerTarget, bool? includeStyleDetails, bool? includeDiagnosticProperties, CockpitSnapshotArtifactMode? artifact, bool? includeRebuildActivity, int? maxRebuildEntries, bool? includeNetworkActivity, int? maxNetworkEntries, CockpitNetworkQuery? networkQuery, bool? includeRuntimeActivity, int? maxRuntimeEntries, CockpitRuntimeQuery? runtimeQuery, bool? includeAccessibilitySummary, int? maxAccessibilityEntries, CockpitWidgetTreeOptions? tree, bool clearTree = false}) CockpitSnapshotOptions
Returns a copy of this CockpitSnapshotOptions with supplied fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitSnapshotOptions as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override