CockpitSnapshotStyle class final
Constructors
- CockpitSnapshotStyle({String? textColor, String? backgroundColor, double? fontSize, String? fontWeight, String? borderSummary, String? shadowSummary})
-
Creates a CockpitSnapshotStyle.
const
-
CockpitSnapshotStyle.fromJson(Map<
String, Object?> json) -
Decodes a CockpitSnapshotStyle from a JSON object.
factory
Properties
- backgroundColor → String?
-
final
- borderSummary → String?
-
final
- fontSize → double?
-
final
- fontWeight → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowSummary → String?
-
final
- textColor → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitSnapshotStyle as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override