CockpitSnapshotTarget class final

Constructors

CockpitSnapshotTarget({required String registrationId, String? cockpitId, String? semanticId, String? keyValue, String? text, String? tooltip, String? typeName, String? path, String? scrollablePath, String? scrollableKeyValue, String? scrollableTypeName, required String routeName, List<CockpitCommandType> supportedCommands = const <CockpitCommandType>[], CockpitSnapshotLayout? layout, CockpitSnapshotContent? content, CockpitSnapshotStyle? style, List<CockpitSnapshotAncestor> ancestors = const <CockpitSnapshotAncestor>[], List<CockpitDiagnosticProperty> diagnosticProperties = const <CockpitDiagnosticProperty>[]})
Creates a CockpitSnapshotTarget.
CockpitSnapshotTarget.fromJson(Map<String, Object?> json)
Decodes a CockpitSnapshotTarget from a JSON object.
factory

Properties

ancestors List<CockpitSnapshotAncestor>
final
cockpitId String?
final
content CockpitSnapshotContent?
final
diagnosticProperties List<CockpitDiagnosticProperty>
final
displayLabel String?
no setter
hashCode int
The hash code for this object.
no setteroverride
keyValue String?
final
layout CockpitSnapshotLayout?
final
path String?
final
registrationId String
final
routeName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollableKeyValue String?
final
scrollablePath String?
final
scrollableTypeName String?
final
semanticId String?
final
style CockpitSnapshotStyle?
final
supportedCommands List<CockpitCommandType>
final
text String?
final
tooltip String?
final
typeName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitSnapshotTarget as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override