CockpitStepRecord class final

Constructors

CockpitStepRecord({required int index, required String actionType, required Map<String, Object?> actionArgs, required DateTime observedAt, CockpitObservation? observation, CockpitSnapshot? snapshot, List<CockpitArtifactRef> artifactRefs = const [], CockpitCommandType? commandType, CockpitLocator? locator, CockpitLocatorResolution? locatorResolution, CockpitCommandError? commandError, int? durationMs, CockpitCommandStatus? status, CockpitTargetKind? targetKind, CockpitPlaneKind? executionPlane, CockpitSurfaceKind? surfaceKind, List<CockpitPlaneKind> fallbackTrail = const <CockpitPlaneKind>[], bool usedPlaneFallback = false, CockpitCaptureProfile? requestedCaptureProfile, CockpitCaptureKind? resolvedCaptureKind, bool usedCaptureFallback = false, String? degradationReason, List<CockpitArtifactRef> captureRefs = const []})
CockpitStepRecord.fromJson(Map<String, Object?> json)
factory

Properties

actionArgs Map<String, Object?>
final
actionType String
final
artifactRefs List<CockpitArtifactRef>
final
captureRefs List<CockpitArtifactRef>
final
commandError CockpitCommandError?
final
commandType CockpitCommandType?
final
degradationReason String?
final
durationMs int?
final
executionPlane CockpitPlaneKind?
final
fallbackTrail List<CockpitPlaneKind>
final
hashCode int
The hash code for this object.
no setteroverride
index int
final
locator CockpitLocator?
final
locatorResolution CockpitLocatorResolution?
final
observation CockpitObservation?
final
observedAt DateTime
final
requestedCaptureProfile CockpitCaptureProfile?
final
resolvedCaptureKind CockpitCaptureKind?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot CockpitSnapshot?
final
status CockpitCommandStatus?
final
surfaceKind CockpitSurfaceKind?
final
targetKind CockpitTargetKind?
final
usedCaptureFallback bool
final
usedPlaneFallback bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override