CockpitStepRecorder class final

Constructors

CockpitStepRecorder({required CockpitTimestampProvider now, required CockpitObservationAssembler observationAssembler})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<CockpitStepRecord>
no setter

Methods

importStepRecords(Iterable<CockpitStepRecord> steps) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordCommandResult(CockpitCommand command, CockpitCommandResult result) → void
recordStep({required String actionType, required Map<String, Object?> actionArgs, CockpitObservation? observation, CockpitSnapshot? snapshot, List<CockpitArtifactRef> artifactRefs = const [], CockpitCommandType? commandType, CockpitLocator? locator, CockpitLocatorResolution? locatorResolution, CockpitCommandError? commandError, int? durationMs, CockpitCommandStatus? status, CockpitTargetKind? targetKind, CockpitPlaneKind? executionPlane, CockpitSurfaceKind? surfaceKind, List<CockpitPlaneKind> fallbackTrail = const <CockpitPlaneKind>[], bool usedPlaneFallback = false, CockpitCaptureProfile? requestedCaptureProfile, CockpitCaptureKind? resolvedCaptureKind, bool usedCaptureFallback = false, String? degradationReason, List<CockpitArtifactRef> captureRefs = const []}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited