CockpitTargetRegistry class final

Constructors

CockpitTargetRegistry({String? routeName})
Creates a CockpitTargetRegistry.

Properties

discoveredTargetsProvider CockpitDiscoveredTargetsProvider?
getter/setter pair
discoveredTargetsReadinessProbe CockpitDiscoveredTargetsReadinessProbe?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasRouteReadyVisibleTargets bool
no setter
registeredTargets List<CockpitTarget>
no setter
routeName String?
getter/setter pair
routeReadyVisibleTargets List<CockpitTarget>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleTargets List<CockpitTarget>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(CockpitTarget target) → void
resolve(CockpitLocator locator, {CockpitCommandType? requiredCommand}) CockpitTargetResolutionResult
resolveCommand(CockpitCommandType commandType) CockpitTargetResolutionResult
routeDiagnostics({int hintLimit = 8}) Map<String, Object?>
snapshot() CockpitSnapshot
toString() String
A string representation of this object.
inherited
unregister(String registrationId) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

candidateDetailLimit → const int
liveSnapshotTargetLimit → const int