CockpitTargetResolutionResult class final

Constructors

CockpitTargetResolutionResult.failure({required CockpitCommandError error, List<CockpitTarget> matches = const <CockpitTarget>[]})
Creates a CockpitTargetResolutionResult using the named constructor failure.
const
CockpitTargetResolutionResult.success({required CockpitTarget target, CockpitLocatorResolution? locatorResolution, List<CockpitTarget> matches = const <CockpitTarget>[]})
Creates a CockpitTargetResolutionResult using the named constructor success.
const

Properties

error CockpitCommandError?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
locatorResolution CockpitLocatorResolution?
final
matches List<CockpitTarget>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target CockpitTarget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited