CockpitTestAction class final

Constructors

CockpitTestAction({required CockpitTestActionKind kind, CockpitTestLocator? locator, CockpitTestCondition? condition, Map<CockpitTestActionField, Object?> values = const <CockpitTestActionField, Object?>{}, Map<String, Object?> extensions = const <String, Object?>{}})
Creates a CockpitTestAction.
CockpitTestAction.fromJson(Object? value, {required String path})
Decodes a CockpitTestAction from a JSON object.
factory

Properties

condition CockpitTestCondition?
final
containsSecret bool
no setter
extensions Map<String, Object?>
final
hashCode int
The hash code for this object.
no setteroverride
kind CockpitTestActionKind
final
locator CockpitTestLocator?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec CockpitTestActionSpec
no setter
values Map<CockpitTestActionField, Object?>
final

Methods

copyWithValues(Map<CockpitTestActionField, Object?> values) CockpitTestAction
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestAction as a JSON object.
toString() String
A string representation of this object.
inherited
value<T>(CockpitTestActionField field) → T?

Operators

operator ==(Object other) bool
The equality operator.
override