CockpitTestActionOperationTemplate class final
- Inheritance
-
- Object
- CockpitTestOperationTemplate
- CockpitTestActionOperationTemplate
Constructors
- CockpitTestActionOperationTemplate(CockpitTestActionTemplate action)
-
Creates a CockpitTestActionOperationTemplate.
const
Properties
- action → CockpitTestActionTemplate
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireName → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
Encodes this CockpitTestActionOperationTemplate as a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited