CockpitTestActionTemplate class final

Constructors

CockpitTestActionTemplate({required CockpitTestActionKind kind, CockpitTestLocatorTemplate? locator, CockpitTestConditionTemplate? condition, Map<CockpitTestActionField, CockpitTestTemplateValue> values = const <CockpitTestActionField, CockpitTestTemplateValue>{}, Map<String, Object?> extensions = const <String, Object?>{}})
Creates a CockpitTestActionTemplate.
CockpitTestActionTemplate.fromJson(Object? value, {required String path})
Decodes a CockpitTestActionTemplate from a JSON object.
factory

Properties

condition CockpitTestConditionTemplate?
final
extensions Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
kind CockpitTestActionKind
final
locator CockpitTestLocatorTemplate?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec CockpitTestActionSpec
no setter
values Map<CockpitTestActionField, CockpitTestTemplateValue>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestActionTemplate as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited