CockpitTestAttemptReport class final

Constructors

CockpitTestAttemptReport({required String attemptId, required int number, required CockpitRunOutcome outcome, required DateTime startedAt, required DateTime finishedAt, required int durationMs, required String targetId, CockpitFailure? failure, Iterable<CockpitArtifactReference> artifacts = const <CockpitArtifactReference>[]})
Creates a CockpitTestAttemptReport.
CockpitTestAttemptReport.fromJson(Object? value, {required String path})
Decodes a CockpitTestAttemptReport from a JSON object.
factory

Properties

artifacts List<CockpitArtifactReference>
final
attemptId String
final
durationMs int
final
failure CockpitFailure?
final
finishedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
number int
final
outcome CockpitRunOutcome
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final
targetId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestAttemptReport as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited