CockpitTestAttemptResult class final

Constructors

CockpitTestAttemptResult({required CockpitTestRunContext context, required CockpitTestLifecycle lifecycle, required CockpitTestOutcome outcome, required CockpitTestStability stability, required DateTime startedAt, required DateTime finishedAt, required int durationMs, required String targetId, required String platform, required CockpitTestPlane requestedPlane, CockpitTestPlane? actualPlane, Iterable<CockpitTestStepResult> steps = const <CockpitTestStepResult>[], CockpitTestError? primaryError, Iterable<CockpitTestError> cleanupErrors = const <CockpitTestError>[], String? bundlePath})
Creates a CockpitTestAttemptResult.
CockpitTestAttemptResult.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestAttemptResult from a JSON object.
factory

Properties

actualPlane CockpitTestPlane?
final
bundlePath String?
final
cleanupErrors List<CockpitTestError>
final
context CockpitTestRunContext
final
durationMs int
final
finishedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
lifecycle CockpitTestLifecycle
final
outcome CockpitTestOutcome
final
platform String
final
primaryError CockpitTestError?
final
requestedPlane CockpitTestPlane
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stability CockpitTestStability
final
startedAt DateTime
final
steps List<CockpitTestStepResult>
final
targetId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestAttemptResult as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited