CockpitTestBundleSummary class final

Constructors

CockpitTestBundleSummary({required String path, required String manifestSha256, required int artifactCount})
Creates a CockpitTestBundleSummary.
CockpitTestBundleSummary.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestBundleSummary from a JSON object.
factory

Properties

artifactCount int
final
hashCode int
The hash code for this object.
no setterinherited
manifestSha256 String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestBundleSummary as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited