CockpitTestCallOperationTemplate class final

Inheritance

Constructors

CockpitTestCallOperationTemplate(String fragment)
Creates a CockpitTestCallOperationTemplate.
CockpitTestCallOperationTemplate.fromJson(Object? value, {required String path})
Decodes a CockpitTestCallOperationTemplate from a JSON object.
factory

Properties

fragment String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
Encodes this CockpitTestCallOperationTemplate as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited