CockpitTestCase class final

Implemented types

Constructors

CockpitTestCase({String schemaVersion = 'cockpit.test/v2', String kind = 'case', required String id, String? name, String? description, Iterable<String> tags = const <String>[], required CockpitTestTargetRequirements target, CockpitTestCaseDefaults defaults = CockpitTestCaseDefaults.standard, Map<String, CockpitTestVariableDeclaration> variables = const <String, CockpitTestVariableDeclaration>{}, Map<String, List<CockpitTestStepTemplate>> fragments = const <String, List<CockpitTestStepTemplate>>{}, Iterable<CockpitTestStepTemplate> setup = const <CockpitTestStepTemplate>[], required Iterable<CockpitTestStepTemplate> steps, Iterable<CockpitTestStepTemplate> finallySteps = const <CockpitTestStepTemplate>[], Map<String, Object?> extensions = const <String, Object?>{}})
Creates a CockpitTestCase.
CockpitTestCase.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestCase from a JSON object.
factory

Properties

defaults CockpitTestCaseDefaults
final
description String?
final
extensions Map<String, Object?>
final
finallySteps List<CockpitTestStepTemplate>
final
fragments Map<String, List<CockpitTestStepTemplate>>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
kind String
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
setup List<CockpitTestStepTemplate>
final
steps List<CockpitTestStepTemplate>
final
tags Set<String>
final
target CockpitTestTargetRequirements
final
variables Map<String, CockpitTestVariableDeclaration>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestCase as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited