CockpitTestCaseReport class final

Constructors

CockpitTestCaseReport({required String entryId, required String caseId, required CockpitTestCase definition, required String sourceSha256, required CockpitRunOutcome outcome, required CockpitRunStability stability, required String targetId, Map<String, Object?> matrix = const <String, Object?>{}, Iterable<CockpitTestAttemptReport> attempts = const <CockpitTestAttemptReport>[]})
Creates a CockpitTestCaseReport.
CockpitTestCaseReport.fromJson(Object? value, {required String path})
Decodes a CockpitTestCaseReport from a JSON object.
factory

Properties

attempts List<CockpitTestAttemptReport>
final
caseId String
final
definition CockpitTestCase
final
entryId String
final
hashCode int
The hash code for this object.
no setterinherited
matrix Map<String, Object?>
final
outcome CockpitRunOutcome
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceSha256 String
final
stability CockpitRunStability
final
targetId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestCaseReport as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited