CockpitTestCondition class final

Constructors

CockpitTestCondition({required CockpitTestConditionKind kind, CockpitTestLocator? locator, bool? expected, String? text, CockpitTextMatchMode? matchMode, String? route, int? quietMs})
Creates a CockpitTestCondition.
CockpitTestCondition.fromJson(Object? value, {required String path})
Decodes a CockpitTestCondition from a JSON object.
factory

Properties

expected bool?
final
hashCode int
The hash code for this object.
no setterinherited
kind CockpitTestConditionKind
final
locator CockpitTestLocator?
final
matchMode CockpitTextMatchMode?
final
quietMs int?
final
route String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestCondition as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited