CockpitTestConditionTemplate class final

Constructors

CockpitTestConditionTemplate({required CockpitTestConditionKind kind, CockpitTestLocatorTemplate? locator, CockpitTestTemplateValue? expected, CockpitTestTemplateValue? text, CockpitTextMatchMode? matchMode, CockpitTestTemplateValue? route, CockpitTestTemplateValue? quietMs})
Creates a CockpitTestConditionTemplate.
CockpitTestConditionTemplate.fromJson(Object? value, {required String path})
Decodes a CockpitTestConditionTemplate from a JSON object.
factory

Properties

expected CockpitTestTemplateValue?
final
hashCode int
The hash code for this object.
no setterinherited
kind CockpitTestConditionKind
final
locator CockpitTestLocatorTemplate?
final
matchMode CockpitTextMatchMode?
final
quietMs CockpitTestTemplateValue?
final
route CockpitTestTemplateValue?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text CockpitTestTemplateValue?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestConditionTemplate as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited