CockpitTestDocument class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
no setter
kind String
no setter
name String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestDocument as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited