CockpitTestErrorCode enum

Inheritance
Available extensions

Values

parseFailed → const CockpitTestErrorCode
schemaUnsupported → const CockpitTestErrorCode
validationFailed → const CockpitTestErrorCode
bindingFailed → const CockpitTestErrorCode
safetyDenied → const CockpitTestErrorCode
secretResolutionFailed → const CockpitTestErrorCode
targetMismatch → const CockpitTestErrorCode
unsupportedAction → const CockpitTestErrorCode
unsupportedLocator → const CockpitTestErrorCode
conditionError → const CockpitTestErrorCode
assertionFailed → const CockpitTestErrorCode
timeout → const CockpitTestErrorCode
cancelled → const CockpitTestErrorCode
hardShutdown → const CockpitTestErrorCode
driverFailed → const CockpitTestErrorCode
recordingFailed → const CockpitTestErrorCode
evidenceFailed → const CockpitTestErrorCode
bundlePublicationFailed → const CockpitTestErrorCode
bundleIntegrityFailed → const CockpitTestErrorCode
internalFailure → const CockpitTestErrorCode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CockpitTestErrorCode>
A constant List of the values in this enum, in order of their declaration.