CockpitTestEvidenceIndexEntry class final
Constructors
-
CockpitTestEvidenceIndexEntry({required int stepResultIndex, required String stepExecutionId, required Iterable<
String> artifactIds}) - Creates a CockpitTestEvidenceIndexEntry.
- CockpitTestEvidenceIndexEntry.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestEvidenceIndexEntry from a JSON object.
factory
Properties
-
artifactIds
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepExecutionId → String
-
final
- stepResultIndex → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestEvidenceIndexEntry as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited