CockpitTestFixture class final

Constructors

CockpitTestFixture({required String id, required CockpitTestSuiteCaseSource setup, CockpitTestSuiteCaseSource? teardown, CockpitTestFixtureScope scope = CockpitTestFixtureScope.caseAttempt, String? targetId, Map<String, Object?> inputs = const <String, Object?>{}, Iterable<String> dependsOn = const <String>[]})
Creates a CockpitTestFixture.
CockpitTestFixture.fromJson(Object? value, {required String path})
Decodes a CockpitTestFixture from a JSON object.
factory

Properties

dependsOn List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
inputs Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope CockpitTestFixtureScope
final
setup CockpitTestSuiteCaseSource
final
targetId String?
final
teardown CockpitTestSuiteCaseSource?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestFixture as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited