CockpitTestIfOperationTemplate class final

Inheritance

Constructors

CockpitTestIfOperationTemplate({required CockpitTestConditionTemplate condition, required Iterable<CockpitTestStepTemplate> thenSteps, Iterable<CockpitTestStepTemplate> elseSteps = const <CockpitTestStepTemplate>[]})
Creates a CockpitTestIfOperationTemplate.
CockpitTestIfOperationTemplate.fromJson(Object? value, {required String path})
Decodes a CockpitTestIfOperationTemplate from a JSON object.
factory

Properties

condition CockpitTestConditionTemplate
final
elseSteps List<CockpitTestStepTemplate>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thenSteps List<CockpitTestStepTemplate>
final
wireName String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
Encodes this CockpitTestIfOperationTemplate as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited