CockpitTestImportMapping class final

Constructors

CockpitTestImportMapping({required String sourcePath, required String destinationPath})
Creates a CockpitTestImportMapping.
CockpitTestImportMapping.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestImportMapping from a JSON object.
factory

Properties

destinationPath String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourcePath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestImportMapping as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited