CockpitTestImportRequest class final

Constructors

CockpitTestImportRequest({required int sourceVersion, required String sourceText, required String projectId, required String workspaceId, required String caseId, required String engineVersion})
Creates a CockpitTestImportRequest.
CockpitTestImportRequest.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestImportRequest from a JSON object.
factory

Properties

caseId String
final
engineVersion String
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceText String
final
sourceVersion int
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestImportRequest as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited