CockpitTestImportResult class final

Constructors

CockpitTestImportResult({required CockpitTestCase testCase, required CockpitTestImportManifest manifest})
Creates a CockpitTestImportResult.
CockpitTestImportResult.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestImportResult from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
manifest CockpitTestImportManifest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testCase CockpitTestCase
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestImportResult as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited