CockpitTestLocator class final

Constructors

CockpitTestLocator({String? text, String? label, CockpitTextMatchMode matchMode = CockpitTextMatchMode.exact, String? nativeId, String? testId, String? role, String? type, String? path, String? visual, double? x, double? y, double? threshold, int? index, bool? enabled, bool? selected, bool? checked, bool? focused, bool? clickable, CockpitTestLocator? ancestor, CockpitTestLocator? child, CockpitTestLocator? descendant, CockpitTestLocator? above, CockpitTestLocator? below, CockpitTestLocator? leftOf, CockpitTestLocator? rightOf, Iterable<CockpitTestLocator> fallbacks = const <CockpitTestLocator>[]})
Creates a CockpitTestLocator.
CockpitTestLocator.fromJson(Object? value, {required String path})
Decodes a CockpitTestLocator from a JSON object.
factory

Properties

above CockpitTestLocator?
final
ancestor CockpitTestLocator?
final
below CockpitTestLocator?
final
checked bool?
final
child CockpitTestLocator?
final
clickable bool?
final
degraded bool
no setter
descendant CockpitTestLocator?
final
enabled bool?
final
fallbacks List<CockpitTestLocator>
final
flattened Iterable<CockpitTestLocator>
no setter
focused bool?
final
hashCode int
The hash code for this object.
no setteroverride
hasNativeOnlyConstraints bool
no setter
index int?
final
label String?
final
leftOf CockpitTestLocator?
final
matchMode CockpitTextMatchMode
final
nativeId String?
final
path String?
final
rightOf CockpitTestLocator?
final
role String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
final
signalMap Map<String, String>
no setter
signals Iterable<({CockpitTestLocatorStrategy strategy, String value})>
no setter
stateMap Map<String, bool>
no setter
strategy CockpitTestLocatorStrategy
no setter
testId String?
final
text String?
final
threshold double?
final
tree Iterable<CockpitTestLocator>
no setter
type String?
final
value String?
no setter
visual String?
final
x double?
final
y double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestLocator as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override