CockpitTestLocatorTemplate class final
Constructors
-
CockpitTestLocatorTemplate({CockpitTestTemplateValue? text, CockpitTestTemplateValue? label, CockpitTestTemplateValue? matchMode, CockpitTestTemplateValue? nativeId, CockpitTestTemplateValue? testId, CockpitTestTemplateValue? role, CockpitTestTemplateValue? type, CockpitTestTemplateValue? path, CockpitTestTemplateValue? visual, CockpitTestTemplateValue? x, CockpitTestTemplateValue? y, CockpitTestTemplateValue? threshold, CockpitTestTemplateValue? index, CockpitTestTemplateValue? enabled, CockpitTestTemplateValue? selected, CockpitTestTemplateValue? checked, CockpitTestTemplateValue? focused, CockpitTestTemplateValue? clickable, CockpitTestLocatorTemplate? ancestor, CockpitTestLocatorTemplate? child, CockpitTestLocatorTemplate? descendant, CockpitTestLocatorTemplate? above, CockpitTestLocatorTemplate? below, CockpitTestLocatorTemplate? leftOf, CockpitTestLocatorTemplate? rightOf, Iterable<
CockpitTestLocatorTemplate> fallbacks = const <CockpitTestLocatorTemplate>[]}) - Creates a CockpitTestLocatorTemplate.
- CockpitTestLocatorTemplate.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestLocatorTemplate from a JSON object.
factory
Properties
- above → CockpitTestLocatorTemplate?
-
final
- ancestor → CockpitTestLocatorTemplate?
-
final
- below → CockpitTestLocatorTemplate?
-
final
- checked → CockpitTestTemplateValue?
-
final
- child → CockpitTestLocatorTemplate?
-
final
- clickable → CockpitTestTemplateValue?
-
final
- degraded → bool
-
no setter
- descendant → CockpitTestLocatorTemplate?
-
final
- enabled → CockpitTestTemplateValue?
-
final
-
fallbacks
→ List<
CockpitTestLocatorTemplate> -
final
- focused → CockpitTestTemplateValue?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → CockpitTestTemplateValue?
-
final
- label → CockpitTestTemplateValue?
-
final
- leftOf → CockpitTestLocatorTemplate?
-
final
- matchMode → CockpitTestTemplateValue?
-
final
- nativeId → CockpitTestTemplateValue?
-
final
- path → CockpitTestTemplateValue?
-
final
- rightOf → CockpitTestLocatorTemplate?
-
final
- role → CockpitTestTemplateValue?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → CockpitTestTemplateValue?
-
final
-
signals
→ Iterable<
({CockpitTestLocatorStrategy strategy, CockpitTestTemplateValue value})> -
no setter
- strategy → CockpitTestLocatorStrategy
-
no setter
- testId → CockpitTestTemplateValue?
-
final
- text → CockpitTestTemplateValue?
-
final
- threshold → CockpitTestTemplateValue?
-
final
- type → CockpitTestTemplateValue?
-
final
- visual → CockpitTestTemplateValue?
-
final
- x → CockpitTestTemplateValue?
-
final
- y → CockpitTestTemplateValue?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestLocatorTemplate as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited