CockpitTestLoopOperationTemplate class final

Inheritance

Constructors

CockpitTestLoopOperationTemplate({required int maxIterations, required CockpitTestConditionTemplate condition, required Iterable<CockpitTestStepTemplate> steps})
Creates a CockpitTestLoopOperationTemplate.
CockpitTestLoopOperationTemplate.fromJson(Object? value, {required String path})
Decodes a CockpitTestLoopOperationTemplate from a JSON object.
factory

Properties

condition CockpitTestConditionTemplate
final
hashCode int
The hash code for this object.
no setterinherited
maxIterations int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<CockpitTestStepTemplate>
final
wireName String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
Encodes this CockpitTestLoopOperationTemplate as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited