CockpitTestMatrix class final

Constructors

CockpitTestMatrix({Map<String, List<Object?>> axes = const <String, List<Object?>>{}, Iterable<Map<String, Object?>> include = const <Map<String, Object?>>[], Iterable<Map<String, Object?>> exclude = const <Map<String, Object?>>[], int maxCombinations = 256})
Creates a CockpitTestMatrix.
CockpitTestMatrix.fromJson(Object? value, {required String path})
Decodes a CockpitTestMatrix from a JSON object.
factory

Properties

axes Map<String, List<Object?>>
final
exclude List<Map<String, Object?>>
final
hashCode int
The hash code for this object.
no setterinherited
include List<Map<String, Object?>>
final
maxCombinations int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestMatrix as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

empty CockpitTestMatrix
final