CockpitTestProject class final

Implemented types

Constructors

CockpitTestProject({String schemaVersion = 'cockpit.test/v2', String kind = 'project', required String id, String? name, String? description, required Iterable<String> suiteSources, Map<String, CockpitTestProjectTarget> targets = const <String, CockpitTestProjectTarget>{}, Iterable<String> allowedSecretProviders = const <String>[], CockpitTestSuiteExecutionPolicy? executionDefaults, CockpitTestSuiteReportPolicy? reportDefaults, Map<String, Object?> extensions = const <String, Object?>{}})
Creates a CockpitTestProject.
CockpitTestProject.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestProject from a JSON object.
factory

Properties

allowedSecretProviders Set<String>
final
description String?
final
executionDefaults CockpitTestSuiteExecutionPolicy
final
extensions Map<String, Object?>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
kind String
final
name String?
final
reportDefaults CockpitTestSuiteReportPolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
suiteSources List<String>
final
targets Map<String, CockpitTestProjectTarget>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestProject as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited