CockpitTestReportBundle class final

Constructors

CockpitTestReportBundle({String schemaVersion = 'cockpit.report.bundle/v2', required DateTime generatedAt, required CockpitTestSuiteReport report, required Iterable<CockpitTestReportExecution> executions, bool complete = true})
Creates a CockpitTestReportBundle.
CockpitTestReportBundle.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestReportBundle from a JSON object.
factory

Properties

complete bool
final
executions List<CockpitTestReportExecution>
final
generatedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
report CockpitTestSuiteReport
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestReportBundle as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited