CockpitTestReportBundleManifest class final
Constructors
-
CockpitTestReportBundleManifest({String schemaVersion = 'cockpit.report.manifest/v2', required String runId, required DateTime createdAt, required Iterable<
CockpitTestReportBundleFile> files}) - Creates a CockpitTestReportBundleManifest.
- CockpitTestReportBundleManifest.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestReportBundleManifest from a JSON object.
factory
Properties
- createdAt → DateTime
-
final
-
files
→ List<
CockpitTestReportBundleFile> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestReportBundleManifest as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited