CockpitTestReportCounts class final

Constructors

CockpitTestReportCounts({required int total, required int passed, required int failed, required int blocked, required int skipped, required int cancelled, required int interrupted, required int internalError, required int flaky})
Creates a CockpitTestReportCounts.
const
CockpitTestReportCounts.fromCases(Iterable<CockpitTestCaseReport> cases)
Creates a CockpitTestReportCounts using the named constructor fromCases.
factory

Properties

blocked int
final
cancelled int
final
failed int
final
flaky int
final
hashCode int
The hash code for this object.
no setterinherited
internalError int
final
interrupted int
final
passed int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipped int
final
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestReportCounts as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited