CockpitTestRetryOperationTemplate class final

Inheritance

Constructors

CockpitTestRetryOperationTemplate({required int maxAttempts, int delayMs = 0, required Iterable<CockpitTestStepTemplate> steps})
Creates a CockpitTestRetryOperationTemplate.
CockpitTestRetryOperationTemplate.fromJson(Object? value, {required String path})
Decodes a CockpitTestRetryOperationTemplate from a JSON object.
factory

Properties

delayMs int
final
hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<CockpitTestStepTemplate>
final
wireName String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
Encodes this CockpitTestRetryOperationTemplate as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited