CockpitTestRunContext class final

Constructors

CockpitTestRunContext({required String projectId, required String workspaceId, required String runId, required String caseId, required String attemptId, required String engineVersion, CockpitAuthorizationMode authorizationMode = CockpitAuthorizationMode.restricted})
Creates a CockpitTestRunContext.
CockpitTestRunContext.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestRunContext from a JSON object.
factory

Properties

attemptId String
final
authorizationMode CockpitAuthorizationMode
final
caseId String
final
engineVersion String
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
final
runId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestRunContext as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited