CockpitTestSafetyDeclaration class final

Constructors

CockpitTestSafetyDeclaration({Iterable<CockpitTestSafetyEffect> effects = const <CockpitTestSafetyEffect>[], String? reason})
Creates a CockpitTestSafetyDeclaration.
CockpitTestSafetyDeclaration.fromJson(Object? value, {required String path})
Decodes a CockpitTestSafetyDeclaration from a JSON object.
factory

Properties

effects Set<CockpitTestSafetyEffect>
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestSafetyDeclaration as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited