CockpitTestSourceMapEntry class final

Constructors

CockpitTestSourceMapEntry({required String path, required CockpitTestSourceLocation location})
Creates a CockpitTestSourceMapEntry.
CockpitTestSourceMapEntry.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestSourceMapEntry from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
location CockpitTestSourceLocation
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestSourceMapEntry as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited