CockpitTestStartPerformanceOperationTemplate class final
Starts an in-app performance capture window.
Performance captures are runner-owned metadata operations rather than ordinary UI commands. Only one window may be active at a time, but a case may contain any number of sequential windows.
- Inheritance
-
- Object
- CockpitTestOperationTemplate
- CockpitTestStartPerformanceOperationTemplate
Constructors
- CockpitTestStartPerformanceOperationTemplate({required String name, String mode = 'profile'})
- CockpitTestStartPerformanceOperationTemplate.fromJson(Object? value, {required String path})
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
Encodes this CockpitTestOperationTemplate as a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited