CockpitTestStepOccurrence class final
Constructors
-
CockpitTestStepOccurrence({int? retryAttempt, int? loopIteration, Iterable<
String> callPath = const <String>[]}) - Creates a CockpitTestStepOccurrence.
- CockpitTestStepOccurrence.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestStepOccurrence from a JSON object.
factory
Properties
-
callPath
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loopIteration → int?
-
final
- retryAttempt → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestStepOccurrence as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited