CockpitTestSuite class final

Implemented types

Constructors

CockpitTestSuite({String schemaVersion = 'cockpit.test/v2', String kind = 'suite', required String id, String? name, String? description, Iterable<String> tags = const <String>[], required Iterable<CockpitTestSuiteEntry> cases, Iterable<CockpitTestFixture> fixtures = const <CockpitTestFixture>[], CockpitTestMatrix? matrix, CockpitTestSuiteExecutionPolicy? execution, CockpitTestSuiteReportPolicy? report, Iterable<String> includeTags = const <String>[], Iterable<String> excludeTags = const <String>[], Map<String, Object?> extensions = const <String, Object?>{}})
Creates a CockpitTestSuite.
CockpitTestSuite.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestSuite from a JSON object.
factory

Properties

cases List<CockpitTestSuiteEntry>
final
description String?
final
excludeTags Set<String>
final
execution CockpitTestSuiteExecutionPolicy
final
extensions Map<String, Object?>
final
fixtures List<CockpitTestFixture>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
includeTags Set<String>
final
kind String
final
matrix CockpitTestMatrix
final
name String?
final
report CockpitTestSuiteReportPolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
tags Set<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestSuite as a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited