CockpitTestSuiteFileCaseSource class final
- Inheritance
-
- Object
- CockpitTestSuiteCaseSource
- CockpitTestSuiteFileCaseSource
Constructors
- CockpitTestSuiteFileCaseSource({required String relativePath, required String caseId})
- Creates a CockpitTestSuiteFileCaseSource.
- CockpitTestSuiteFileCaseSource.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestSuiteFileCaseSource from a JSON object.
factory
Properties
- caseId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
no setteroverride
- relativePath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Encodes this CockpitTestSuiteFileCaseSource as a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited