CockpitTestSuiteReport class final

Constructors

CockpitTestSuiteReport({String schemaVersion = 'cockpit.report/v2', required String projectId, required String workspaceId, required String runId, required String suiteId, required CockpitTestSuite definition, required String sourceSha256, required CockpitRunOutcome outcome, required CockpitRunStability stability, required DateTime startedAt, required DateTime finishedAt, required int durationMs, required CockpitTestSuiteExecutionPolicy execution, required CockpitTestSuiteReportPolicy reportPolicy, CockpitFailure? failure, Map<String, Object?> environment = const <String, Object?>{}, Map<String, List<Object?>> matrixAxes = const <String, List<Object?>>{}, required Iterable<CockpitTestCaseReport> cases, Iterable<CockpitArtifactReference> artifacts = const <CockpitArtifactReference>[], bool complete = true})
Creates a CockpitTestSuiteReport.
CockpitTestSuiteReport.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitTestSuiteReport from a JSON object.
factory

Properties

artifacts List<CockpitArtifactReference>
final
cases List<CockpitTestCaseReport>
final
complete bool
final
counts CockpitTestReportCounts
no setter
definition CockpitTestSuite
final
durationMs int
final
environment Map<String, Object?>
final
execution CockpitTestSuiteExecutionPolicy
final
failure CockpitFailure?
final
finishedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
matrixAxes Map<String, List<Object?>>
final
outcome CockpitRunOutcome
final
projectId String
final
reportPolicy CockpitTestSuiteReportPolicy
final
runId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
sourceSha256 String
final
stability CockpitRunStability
final
startedAt DateTime
final
suiteId String
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestSuiteReport as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited