CockpitTestSuiteReportPolicy class final

Constructors

CockpitTestSuiteReportPolicy({Iterable<CockpitTestReportFormat> formats = const <CockpitTestReportFormat>[CockpitTestReportFormat.json, CockpitTestReportFormat.junit, CockpitTestReportFormat.html, CockpitTestReportFormat.summary], bool includePassedAttempts = true})
Creates a CockpitTestSuiteReportPolicy.
CockpitTestSuiteReportPolicy.fromJson(Object? value, {required String path})
Decodes a CockpitTestSuiteReportPolicy from a JSON object.
factory

Properties

formats Set<CockpitTestReportFormat>
final
hashCode int
The hash code for this object.
no setterinherited
includePassedAttempts bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestSuiteReportPolicy as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

standard CockpitTestSuiteReportPolicy
final