CockpitTestTargetRequirements class final

Constructors

CockpitTestTargetRequirements({required String platform, required String targetKind, required CockpitTestPlane plane, String? appId, Iterable<String> requiredCapabilities = const <String>[]})
Creates a CockpitTestTargetRequirements.
CockpitTestTargetRequirements.fromJson(Object? value, {required String path})
Decodes a CockpitTestTargetRequirements from a JSON object.
factory

Properties

appId String?
final
hashCode int
The hash code for this object.
no setterinherited
plane CockpitTestPlane
final
platform String
final
requiredCapabilities Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetKind String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestTargetRequirements as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited