CockpitTestTemplateValue class final

Constructors

CockpitTestTemplateValue.fromJson(Object? value, {required CockpitTestValueType expectedType, required String path})
Decodes a CockpitTestTemplateValue from a JSON object.
factory
CockpitTestTemplateValue.literal(Object? value, {required CockpitTestValueType expectedType})
Creates a CockpitTestTemplateValue using the named constructor literal.
CockpitTestTemplateValue.stringTemplate(String template)
Creates a CockpitTestTemplateValue using the named constructor stringTemplate.
CockpitTestTemplateValue.variable(String? variable, {required CockpitTestValueType expectedType})
Creates a CockpitTestTemplateValue using the named constructor variable.

Properties

expectedType CockpitTestValueType
final
hashCode int
The hash code for this object.
no setteroverride
kind CockpitTestTemplateValueKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
final
variable String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
Encodes this CockpitTestTemplateValue as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override