CockpitTestVariableDeclaration class final

Constructors

CockpitTestVariableDeclaration({required CockpitTestVariableSource source, required CockpitTestValueType valueType, Object? value = _absentVariableValue, Object? defaultValue = _absentVariableValue, bool required = true, String? secretReference})
Creates a CockpitTestVariableDeclaration.
CockpitTestVariableDeclaration.fromJson(Object? value, {required String path})
Decodes a CockpitTestVariableDeclaration from a JSON object.
factory

Properties

defaultValue Object?
final
hasDefaultValue bool
final
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretReference String?
final
source CockpitTestVariableSource
final
value Object?
final
valueType CockpitTestValueType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTestVariableDeclaration as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited