CockpitTextInputAction enum

Inheritance
Available extensions

Values

done → const CockpitTextInputAction
next → const CockpitTextInputAction
previous → const CockpitTextInputAction
send → const CockpitTextInputAction
go → const CockpitTextInputAction
newline → const CockpitTextInputAction
none → const CockpitTextInputAction
unspecified → const CockpitTextInputAction
continueAction → const CockpitTextInputAction
emergencyCall → const CockpitTextInputAction
join → const CockpitTextInputAction
route → const CockpitTextInputAction

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeFromJson(Object? json) CockpitTextInputAction?

Constants

values → const List<CockpitTextInputAction>
A constant List of the values in this enum, in order of their declaration.