CockpitTextInputRequest class final

Constructors

CockpitTextInputRequest({String? text, int? selectionBase, int? selectionExtent, int? composingBase, int? composingExtent, CockpitTextInputAction? inputAction, bool requestFocus = true, bool clearExisting = false})
Creates a CockpitTextInputRequest.
const
CockpitTextInputRequest.fromJson(Map<String, Object?> json)
Decodes a CockpitTextInputRequest from a JSON object.
factory

Properties

clearExisting bool
final
composingBase int?
UTF-16 composing range used by IMEs and platform text input.
final
composingExtent int?
final
hasEditingMutation bool
no setter
hashCode int
The hash code for this object.
no setteroverride
inputAction CockpitTextInputAction?
final
requestFocus bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionBase int?
final
selectionExtent int?
final
text String?
final

Methods

copyWith({String? text, int? selectionBase, int? selectionExtent, int? composingBase, int? composingExtent, CockpitTextInputAction? inputAction, bool? requestFocus, bool? clearExisting, bool clearText = false, bool clearSelectionBase = false, bool clearSelectionExtent = false, bool clearComposingBase = false, bool clearComposingExtent = false, bool clearInputAction = false}) CockpitTextInputRequest
Returns a copy of this CockpitTextInputRequest with supplied fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitTextInputRequest as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override