CockpitViewportResizeRequest class final

Constructors

CockpitViewportResizeRequest({required int width, required int height})
Creates a CockpitViewportResizeRequest.
const
CockpitViewportResizeRequest.fromJson(Map<String, Object?> json)
Decodes a CockpitViewportResizeRequest from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitViewportResizeRequest as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited