CockpitWebSocketActivity class final

Constructors

CockpitWebSocketActivity({required int sentFrames, required int receivedFrames, required int sentBytes, required int receivedBytes, required List<CockpitWebSocketFrame> recentFrames, bool framesTruncated = false})
Creates a CockpitWebSocketActivity.
const
CockpitWebSocketActivity.fromJson(Map<String, Object?> json)
Decodes a CockpitWebSocketActivity from a JSON object.
factory

Properties

framesTruncated bool
final
hashCode int
The hash code for this object.
no setteroverride
receivedBytes int
final
receivedFrames int
final
recentFrames List<CockpitWebSocketFrame>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentBytes int
final
sentFrames int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitWebSocketActivity as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override