CockpitWidgetBounds class final

Constructors

CockpitWidgetBounds({required double x, required double y, required double width, required double height, String? constraints})
Creates global logical bounds for a mounted Widget node.
const
CockpitWidgetBounds.fromJson(Map<String, Object?> json)
Decodes Widget bounds from a JSON object.
factory

Properties

constraints String?
Bounded render constraints included by the full profile.
final
hashCode int
The hash code for this object.
no setteroverride
height double
Logical height.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
Logical width.
final
x double
Global logical x coordinate.
final
y double
Global logical y coordinate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes these bounds as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override