CockpitWidgetProperty class final

Constructors

CockpitWidgetProperty({required String name, required String value})
Creates one bounded diagnostic property.
const
CockpitWidgetProperty.fromJson(Map<String, Object?> json)
Decodes a Widget diagnostic property from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
Diagnostic property name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Normalized bounded diagnostic value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this property as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override