CockpitWidgetTreeProfile enum
Values
- minimal → const CockpitWidgetTreeProfile
-
const CockpitWidgetTreeProfile('minimal') - standard → const CockpitWidgetTreeProfile
-
const CockpitWidgetTreeProfile('standard') - full → const CockpitWidgetTreeProfile
-
const CockpitWidgetTreeProfile('full')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- jsonValue → String
-
Value used by JSON, LON, and YAML projections.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json) → CockpitWidgetTreeProfile - Decodes a widget-tree profile from its serialized value.
Constants
-
values
→ const List<
CockpitWidgetTreeProfile> - A constant List of the values in this enum, in order of their declaration.