CockpitWorkspaceMarker class final

Constructors

CockpitWorkspaceMarker({String schemaVersion = 'cockpit.workspace/v2', required String workspaceId, required String projectId, required String checkoutId, required DateTime createdAt})
Creates a CockpitWorkspaceMarker.
CockpitWorkspaceMarker.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitWorkspaceMarker from a JSON object.
factory

Properties

checkoutId String
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion String
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitWorkspaceMarker as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited