CockpitWorkspaceRebind class final
Constructors
- CockpitWorkspaceRebind({required String path, required String expectedCheckoutId})
- Creates a CockpitWorkspaceRebind.
- CockpitWorkspaceRebind.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitWorkspaceRebind from a JSON object.
factory
Properties
- expectedCheckoutId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitWorkspaceRebind as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited