CockpitWorkspaceRegistration class final

Constructors

CockpitWorkspaceRegistration({required String rootId, required String path})
Creates a CockpitWorkspaceRegistration.
CockpitWorkspaceRegistration.fromJson(Object? value, {String path = r'$'})
Decodes a CockpitWorkspaceRegistration from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
final
rootId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitWorkspaceRegistration as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited