CockpitWorkspaceResource class final

Constructors

CockpitWorkspaceResource({required String workspaceId, required String projectId, required String checkoutId, required String rootId, required String canonicalPath, required String filesystemIdentity, required CockpitWorkspaceState state, required DateTime registeredAt, required DateTime updatedAt})
Creates a CockpitWorkspaceResource.
CockpitWorkspaceResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitWorkspaceResource from a JSON object.
factory

Properties

canonicalPath String
final
checkoutId String
final
filesystemIdentity String
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
final
registeredAt DateTime
final
rootId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CockpitWorkspaceState
final
updatedAt DateTime
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitWorkspaceResource as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited