CockpitDiscoveryPolicy class final
Constructors
- CockpitDiscoveryPolicy({CockpitDiscoveryElementPredicate? isInteractiveWidget, CockpitDiscoveryElementPredicate? shouldStopTraversal, CockpitDiscoveryElementPredicate? isIgnoredSubtree, CockpitDiscoveryElementPredicate? isScrollableBoundary, CockpitDiscoveryStringExtractor? extractText, CockpitDiscoveryStringExtractor? extractSemanticId, CockpitDiscoveryStringExtractor? extractTooltip, CockpitDiscoveryStringExtractor? extractKey, CockpitTapHandlerResolver? tapHandlerForElement, CockpitLongPressHandlerResolver? longPressHandlerForElement, CockpitDoubleTapHandlerResolver? doubleTapHandlerForElement, CockpitEnterTextHandlerResolver? enterTextHandlerForElement, CockpitTextInputHandlerResolver? textInputHandlerForElement})
-
const
- CockpitDiscoveryPolicy.material({CockpitDiscoveryElementPredicate? isInteractiveWidget, CockpitDiscoveryElementPredicate? shouldStopTraversal, CockpitDiscoveryElementPredicate? isIgnoredSubtree, CockpitDiscoveryElementPredicate? isScrollableBoundary, CockpitDiscoveryStringExtractor? extractText, CockpitDiscoveryStringExtractor? extractSemanticId, CockpitDiscoveryStringExtractor? extractTooltip, CockpitDiscoveryStringExtractor? extractKey, CockpitTapHandlerResolver? tapHandlerForElement, CockpitLongPressHandlerResolver? longPressHandlerForElement, CockpitDoubleTapHandlerResolver? doubleTapHandlerForElement, CockpitEnterTextHandlerResolver? enterTextHandlerForElement, CockpitTextInputHandlerResolver? textInputHandlerForElement})
-
factory
Properties
- doubleTapHandlerForElement → CockpitDoubleTapHandlerResolver?
-
final
- enterTextHandlerForElement → CockpitEnterTextHandlerResolver?
-
final
- extractKey → CockpitDiscoveryStringExtractor?
-
final
- extractSemanticId → CockpitDiscoveryStringExtractor?
-
final
- extractText → CockpitDiscoveryStringExtractor?
-
final
- extractTooltip → CockpitDiscoveryStringExtractor?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIgnoredSubtree → CockpitDiscoveryElementPredicate?
-
final
- isInteractiveWidget → CockpitDiscoveryElementPredicate?
-
final
- isScrollableBoundary → CockpitDiscoveryElementPredicate?
-
final
- longPressHandlerForElement → CockpitDoubleTapHandlerResolver?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldStopTraversal → CockpitDiscoveryElementPredicate?
-
final
- tapHandlerForElement → CockpitDoubleTapHandlerResolver?
-
final
- textInputHandlerForElement → CockpitTextInputHandlerResolver?
-
final
Methods
-
copyWith(
{CockpitDiscoveryElementPredicate? isInteractiveWidget, CockpitDiscoveryElementPredicate? shouldStopTraversal, CockpitDiscoveryElementPredicate? isIgnoredSubtree, CockpitDiscoveryElementPredicate? isScrollableBoundary, CockpitDiscoveryStringExtractor? extractText, CockpitDiscoveryStringExtractor? extractSemanticId, CockpitDiscoveryStringExtractor? extractTooltip, CockpitDiscoveryStringExtractor? extractKey, CockpitTapHandlerResolver? tapHandlerForElement, CockpitLongPressHandlerResolver? longPressHandlerForElement, CockpitDoubleTapHandlerResolver? doubleTapHandlerForElement, CockpitEnterTextHandlerResolver? enterTextHandlerForElement, CockpitTextInputHandlerResolver? textInputHandlerForElement}) → CockpitDiscoveryPolicy -
ignoresSubtree(
Element element) → bool -
marksScrollableBoundary(
Element element) → bool -
matchesInteractiveWidget(
Element element) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stopsTraversal(
Element element) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited