CockpitFlutterRuntimeObserver class final
- Implemented types
Constructors
- CockpitFlutterRuntimeObserver({required CockpitRuntimeCurrentRouteProvider routeNameProvider, CockpitRuntimeCriticalEventHandler? onCriticalEvent, bool captureDebugPrint = true, bool capturePrint = true, int maxRetainedEvents = 120, int maxMessageLength = 512, int maxDetailLength = 512, int maxStackTraceLines = 12})
Properties
- captureDebugPrint → bool
-
final
- capturePrint → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDetailLength → int
-
final
- maxMessageLength → int
-
final
- maxRetainedEvents → int
-
final
- maxStackTraceLines → int
-
final
- onCriticalEvent → CockpitRuntimeCriticalEventHandler?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
override
-
dispose(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordDebugLog(
String? message, {String? source, Map< String, String> details = const <String, String>{}}) → void -
recordFlutterFrameworkError(
FlutterErrorDetails details, {String? source}) → void -
recordUnhandledError(
Object error, StackTrace stackTrace, {String? source}) → void -
runWithDiagnosticsZone<
T> (T body(), {void onError(Object error, StackTrace stackTrace)?}) → T -
snapshot(
{int maxEntries = 8, CockpitRuntimeQuery query = const CockpitRuntimeQuery()}) → CockpitRuntimeSnapshot -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited