CockpitHttpNetworkObserver class final
- Inheritance
-
- Object
- HttpOverrides
- CockpitHttpNetworkObserver
- Implemented types
Constructors
- CockpitHttpNetworkObserver({int maxRetainedEntries = 200, int maxHeaderCount = 24, int maxHeaderValueLength = 256, int maxBodyBytes = 4096, bool captureHeaders = true, bool captureBodies = true, CockpitNetworkTickHandler? tickHandler})
Properties
- captureBodies → bool
-
final
- captureHeaders → bool
-
final
- hasAttachedParentOverrides → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBodyBytes → int
-
final
- maxHeaderCount → int
-
final
- maxHeaderValueLength → int
-
final
- maxRetainedEntries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attachParentOverrides(
HttpOverrides? overrides) → void -
clear(
) → void -
override
-
createHttpClient(
SecurityContext? context) → HttpClient -
Returns a new HttpClient using the given
context.override -
findProxyFromEnvironment(
Uri url, Map< String, String> ? environment) → String -
Resolves the proxy server to be used for HTTP connections.
inherited
-
markRequestStarted(
) → void -
nextRequestId(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previewBytes(
List< int> bytes) → String? -
snapshot(
{int maxEntries = 10, CockpitNetworkQuery query = const CockpitNetworkQuery()}) → CockpitNetworkSnapshot -
override
-
snapshotHeaders(
HttpHeaders headers) → Map< String, String> -
toString(
) → String -
A string representation of this object.
inherited
-
waitForIdle(
{Duration quietWindow = const Duration(milliseconds: 150), Duration timeout = const Duration(seconds: 2)}) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited