CockpitKeyEventRequest class final
Constructors
- CockpitKeyEventRequest({required LogicalKeyboardKey logicalKey, PhysicalKeyboardKey? physicalKey, String? character})
-
const
-
CockpitKeyEventRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- character → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logicalKey → LogicalKeyboardKey
-
final
- physicalKey → PhysicalKeyboardKey?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited