CockpitNativeRecording class
Constructors
- CockpitNativeRecording({MethodChannel? channel})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryCapabilities(
) → Future< CockpitRecordingCapabilities> -
startRecording(
{required CockpitRecordingRequest request}) → Future< CockpitRecordingSession> -
stopRecording(
{required CockpitRecordingSession session}) → Future< CockpitRecordingResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited