CockpitRebuildTracker class final
Constructors
- CockpitRebuildTracker({required String routeNameProvider(), int maxTrackedEntries = 120})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTrackedEntries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
snapshot(
{int maxEntries = 8}) → CockpitRebuildSnapshot -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited