CockpitSurfaceState class
final
Methods
-
activate()
→ void
-
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
captureScreenshot(CockpitScreenshotRequest request, {double pixelRatio = 1.0})
→ Future<CockpitCapturedScreenshot>
-
-
deactivate()
→ void
-
Called when this object is removed from the tree.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
didChangeDependencies()
→ void
-
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(covariant CockpitSurface oldWidget)
→ void
-
Called whenever the widget configuration changes.
override
-
dispose()
→ void
-
Called when this object is removed from the tree permanently.
override
-
ensureLocatorVisible(CockpitLocator locator, {Duration duration = const Duration(milliseconds: 220), CockpitRevealAlignment alignment = CockpitRevealAlignment.nearest, double padding = 0})
→ Future<bool>
-
-
initState()
→ void
-
Called when this object is inserted into the tree.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
performGesture(CockpitGestureAction action)
→ Future<void>
-
-
reassemble()
→ void
-
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
scrollByViewport({bool reverse = false, double viewportFraction = 0.8, String? scrollableKey, CockpitLocator? targetLocator, CockpitLocator? scrollableLocator, Duration duration = const Duration(milliseconds: 220), CockpitGestureProfile gestureProfile = CockpitGestureProfile.userLike, bool continuous = false, bool postScrollEnsureVisible = true, bool probeDuringScroll = true})
→ Future<CockpitScrollStepResult>
-
-
setState(VoidCallback fn)
→ void
-
Notify the framework that the internal state of this object has changed.
inherited
-
snapshot({CockpitSnapshotOptions options = const CockpitSnapshotOptions()})
→ CockpitSnapshot
-
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited