FlutterCockpit class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

binding FlutterCockpitBinding
no setter
isInitialized bool
no setter
no setter
performanceCollector CockpitPerformanceCollector
The explicit performance collector owned by this runtime session.
no setter
performancePlugins CockpitPerformancePluginRegistry
Plugins configured for the current development runtime.
no setter

Static Methods

bindRouteInformationProvider(RouteInformationProvider provider) VoidCallback
Binds a public Flutter router provider, including providers exposed by go_router and other Router-based packages.
bootstrap([FlutterCockpitConfig config = const FlutterCockpitConfig.production()]) FlutterCockpitBinding
clearRecordedSteps() → void
createNavigatorObserver() NavigatorObserver
Creates a navigator observer for a nested Navigator or router-managed navigator. Each Navigator must receive its own observer instance.
dispose() → void
drainRecordedSteps({bool clear = true}) List<CockpitStepRecord>
ensureInitialized([FlutterCockpitConfig config = const FlutterCockpitConfig.production()]) FlutterCockpitBinding
initialize([FlutterCockpitConfiguration configuration = const FlutterCockpitConfiguration()]) FlutterCockpitBinding
recordStep({required String actionType, required Map<String, Object?> actionArgs, CockpitObservation? observation, CockpitSnapshot? snapshot, List<CockpitArtifactRef> artifactRefs = const [], CockpitCommandType? commandType, CockpitLocator? locator, CockpitLocatorResolution? locatorResolution, int? durationMs, CockpitCommandStatus? status, CockpitCaptureProfile? requestedCaptureProfile, CockpitCaptureKind? resolvedCaptureKind, bool usedCaptureFallback = false, String? degradationReason, List<CockpitArtifactRef> captureRefs = const []}) → void
runApp(Widget child, {FlutterCockpitConfig config = const FlutterCockpitConfig.production()}) → void
setCurrentRouteName(String routeName) → void