rootKey property

Key forwarded to the mounted FlutterCockpitRoot.

Development-only test harnesses can use this to obtain the live root controller without relying on a broad widget-tree lookup.

Implementation

final GlobalKey<FlutterCockpitRootState>? rootKey;