FlutterCockpitRootState class
final
Methods
activate ()
→ void
Called when this object is reinserted into the tree after having been
removed via deactivate .
inherited
build (BuildContext context )
→ Widget
Describes the part of the user interface represented by this widget.
override
captureScreenshot (CockpitScreenshotRequest request , {CockpitCaptureProfile ? profile , bool ? allowFallback , bool waitForIdle = true })
→ Future <CockpitCaptureResult >
createCommandExecutor ({String ? platform , String transportType = 'inAppTest' , Future <void > postActionSettler ()?, Future <void > waitTickHandler (Duration duration )? })
→ InAppCockpitCommandExecutor
Creates the same in-app command executor used by the remote Cockpit
bridge.
deactivate ()
→ void
Called when this object is removed from the tree.
inherited
debugFillProperties (DiagnosticPropertiesBuilder properties )
→ void
Add additional properties associated with the node.
inherited
didChangeDependencies ()
→ void
Called when a dependency of this State object changes.
inherited
didUpdateWidget (covariant FlutterCockpitRoot oldWidget )
→ void
Called whenever the widget configuration changes.
override
dispose ()
→ void
Called when this object is removed from the tree permanently.
override
initState ()
→ void
Called when this object is inserted into the tree.
override
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performGesture (CockpitGestureAction action )
→ Future <void >
queryRecordingCapabilities ()
→ Future <CockpitRecordingCapabilities >
reassemble ()
→ void
Called whenever the application is reassembled during debugging, for
example during hot reload.
override
remoteSessionStatus ()
→ Future <CockpitRemoteSessionStatus >
resizeViewport (CockpitViewportResizeRequest request )
→ Future <CockpitViewportResizeResult >
Resizes the native viewport when the current platform exposes that
capability. The result reports an unavailable capability instead of
pretending that the logical size changed.
setState (VoidCallback fn )
→ void
Notify the framework that the internal state of this object has changed.
inherited
snapshot ({CockpitSnapshotOptions options = const CockpitSnapshotOptions() })
→ CockpitSnapshot
startRecording (CockpitRecordingRequest request )
→ Future <CockpitRecordingSession >
stopRecording ()
→ Future <CockpitRecordingResult >
toDiagnosticsNode ({String ? name , DiagnosticsTreeStyle ? style })
→ DiagnosticsNode
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep .
inherited
toString ({DiagnosticLevel minLevel = DiagnosticLevel.info })
→ String
A string representation of this object.
inherited
toStringShort ()
→ String
A brief description of this object, usually just the runtimeType and the
hashCode .
inherited
waitForRemoteSession ()
→ Future <Uri ? >
waitForUiIdle ({Duration ? quietWindow , Duration ? timeout , bool ? includeNetworkIdle })
→ Future <bool >