resizeViewport method

Resizes the native viewport when the current platform exposes that capability. The result reports an unavailable capability instead of pretending that the logical size changed.

Implementation

Future<CockpitViewportResizeResult> resizeViewport(
  CockpitViewportResizeRequest request,
) {
  return _resizeRemoteViewport(request);
}