FlutterViewCapture class final

Constructors

FlutterViewCapture()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture({required GlobalKey<State<StatefulWidget>> repaintBoundaryKey, required CockpitScreenshotRequest request, CockpitSnapshot? snapshot, double pixelRatio = 1.0}) Future<CockpitCapturedScreenshot>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited