InAppCockpitCommandExecutor class final

Implemented types

Constructors

InAppCockpitCommandExecutor({required CockpitTargetRegistry registry, CockpitCaptureHandler? captureHandler, CockpitSnapshotProvider? snapshotProvider, CockpitPostActionSettler? postActionSettler, CockpitScrollStepHandler? scrollStepHandler, CockpitEnsureVisibleHandler? ensureVisibleHandler, CockpitGestureHandler? gestureHandler, CockpitNetworkActivityClearer? clearNetworkActivityHandler, CockpitNetworkIdleWaiter? waitForNetworkIdleHandler, CockpitBackNavigationHandler? backNavigationHandler, CockpitWaitTickHandler? waitTickHandler, CockpitKeyEventHandler? keyEventHandler, CockpitInteractionPolicy interactionPolicy = const CockpitInteractionPolicy(), CockpitRecordingActivityProbe? isRecordingActive, String platform = 'flutter', String transportType = 'inApp'})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describeCapabilities() Future<CockpitCapabilities>
override
execute(CockpitCommand command) Future<CockpitCommandResult>
override
executeWithArtifacts(CockpitCommand command) Future<CockpitCommandExecution>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited