CockpitRemoteBridgeResponse class final

Constructors

CockpitRemoteBridgeResponse({required String requestId, required int statusCode, String contentType = 'application/json', Map<String, Object?>? jsonBody, String? bytesBase64})
const
CockpitRemoteBridgeResponse.fromEndpointResponse({required String requestId, required CockpitRemoteSessionEndpointResponse response})
factory
CockpitRemoteBridgeResponse.fromJson(Map<String, Object?> json)
factory

Properties

binaryBody List<int>?
no setter
bytesBase64 String?
final
contentType String
final
hashCode int
The hash code for this object.
no setterinherited
jsonBody Map<String, Object?>?
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited