CockpitRemoteSessionEndpointHandler class final
Constructors
- CockpitRemoteSessionEndpointHandler({required CockpitRemoteSessionConfiguration configuration, required CockpitRemoteSessionStatusProvider statusProvider, CockpitRemoteSessionReadyProvider? readyProvider, required CockpitRemoteSessionSnapshotProvider snapshotProvider, required CockpitRemoteSessionCommandExecutor commandExecutor, CockpitRemoteRuntimeStepDrainer? runtimeStepDrainer, required CockpitRemoteRecordingStarter startRecording, required CockpitRemoteRecordingStopper stopRecording, CockpitRemoteArtifactTempFileFactory? artifactTempFileFactory})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
handle(
CockpitRemoteSessionEndpointRequest request) → Future< CockpitRemoteSessionEndpointResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited