CockpitApiError class final
Constructors
-
CockpitApiError({required String code, required CockpitErrorCategory category, required String message, required bool retryable, required CockpitResponsibleLayer responsibleLayer, Map<
String, Object?> redactedDetails = const <String, Object?>{}, Iterable<CockpitArtifactReference> artifacts = const <CockpitArtifactReference>[]}) - Creates a CockpitApiError.
- CockpitApiError.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
-
Decodes a CockpitApiError from a JSON object.
factory
Properties
-
artifacts
→ List<
CockpitArtifactReference> -
final
- category → CockpitErrorCategory
-
final
- code → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
-
redactedDetails
→ Map<
String, Object?> -
final
- responsibleLayer → CockpitResponsibleLayer
-
final
- retryable → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitApiError as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited