CockpitArtifactResource class final
Constructors
- CockpitArtifactResource({required String artifactId, required String workspaceId, required String runId, required String kind, required String relativePath, required String mediaType, required int sizeBytes, required String sha256, required DateTime createdAt, required String downloadUrl, String? attemptId, String? stepExecutionId})
- Creates a CockpitArtifactResource.
- CockpitArtifactResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
-
Decodes a CockpitArtifactResource from a JSON object.
factory
Properties
- artifactId → String
-
final
- attemptId → String?
-
final
- createdAt → DateTime
-
final
- downloadUrl → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- mediaType → String
-
final
- reference → CockpitArtifactReference
-
no setter
- relativePath → String
-
final
- runId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
final
- sizeBytes → int
-
final
- stepExecutionId → String?
-
final
- workspaceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitArtifactResource as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited