CockpitCapabilities class final
Constructors
-
CockpitCapabilities({required String platform, required String transportType, required bool supportsInAppControl, required bool supportsFlutterViewCapture, required bool supportsNativeScreenCapture, required bool supportsHostAutomation, bool supportsViewportResize = false, String? viewportResizeAlternative, List<
CockpitCommandType> supportedCommands = const <CockpitCommandType>[], List<CockpitLocatorKind> supportedLocatorStrategies = const <CockpitLocatorKind>[], CockpitCapabilityProfile? capabilityProfile}) - Creates a CockpitCapabilities.
-
CockpitCapabilities.fromJson(Map<
String, Object?> json) -
Decodes a CockpitCapabilities from a JSON object.
factory
Properties
- capabilityProfile → CockpitCapabilityProfile?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- platform → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedCommands
→ List<
CockpitCommandType> -
final
-
supportedLocatorStrategies
→ List<
CockpitLocatorKind> -
final
- supportsFlutterViewCapture → bool
-
final
- supportsHostAutomation → bool
-
final
- supportsInAppControl → bool
-
final
- supportsNativeScreenCapture → bool
-
final
- supportsViewportResize → bool
-
final
- transportType → String
-
final
- viewportResizeAlternative → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitCapabilities as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override