CockpitCapabilities class final

Constructors

CockpitCapabilities({required String platform, required String transportType, required bool supportsInAppControl, required bool supportsFlutterViewCapture, required bool supportsNativeScreenCapture, required bool supportsHostAutomation, List<CockpitCommandType> supportedCommands = const <CockpitCommandType>[], List<CockpitLocatorKind> supportedLocatorStrategies = const <CockpitLocatorKind>[], CockpitCapabilityProfile? capabilityProfile})
CockpitCapabilities.fromJson(Map<String, Object?> json)
factory

Properties

capabilityProfile CockpitCapabilityProfile?
final
hashCode int
The hash code for this object.
no setteroverride
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedCommands List<CockpitCommandType>
final
supportedLocatorStrategies List<CockpitLocatorKind>
final
supportsFlutterViewCapture bool
final
supportsHostAutomation bool
final
supportsInAppControl bool
final
supportsNativeScreenCapture bool
final
transportType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override