CockpitCapabilityDocument class final
Constructors
-
CockpitCapabilityDocument({String schemaVersion = 'cockpit.foundation/v2', required CockpitApiVersion apiVersion, Iterable<
CockpitFeatureDescriptor> features = const <CockpitFeatureDescriptor>[], Iterable<CockpitOperationDescriptor> operations = const <CockpitOperationDescriptor>[], Iterable<CockpitResourceDescriptor> resources = const <CockpitResourceDescriptor>[]}) - Creates a CockpitCapabilityDocument.
- CockpitCapabilityDocument.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
-
Decodes a CockpitCapabilityDocument from a JSON object.
factory
Properties
- apiVersion → CockpitApiVersion
-
final
-
features
→ List<
CockpitFeatureDescriptor> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
operations
→ List<
CockpitOperationDescriptor> -
final
-
resources
→ List<
CockpitResourceDescriptor> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitCapabilityDocument as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited