CockpitCaptureResult class final
Constructors
- CockpitCaptureResult({required CockpitCapturedScreenshot screenshot, required CockpitCaptureProfile requestedProfile, required CockpitCaptureKind resolvedCaptureKind, bool usedFallback = false, String? degradationReason})
-
const
Properties
- degradationReason → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestedProfile → CockpitCaptureProfile
-
final
- resolvedCaptureKind → CockpitCaptureKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenshot → CockpitCapturedScreenshot
-
final
- usedFallback → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited