CockpitCommand class final

Constructors

CockpitCommand({required String commandId, required CockpitCommandType commandType, CockpitLocator? locator, Map<String, Object?> parameters = const <String, Object?>{}, CockpitCapturePolicy capturePolicy = CockpitCapturePolicy.none, CockpitCaptureFailurePolicy captureFailurePolicy = CockpitCaptureFailurePolicy.failCommand, int? timeoutMs, CockpitSnapshotOptions? snapshotOptions, CockpitScreenshotRequest? screenshotRequest})
CockpitCommand.fromJson(Map<String, Object?> json)
factory

Properties

captureFailurePolicy CockpitCaptureFailurePolicy
final
capturePolicy CockpitCapturePolicy
final
commandId String
final
commandType CockpitCommandType
final
hashCode int
The hash code for this object.
no setteroverride
locator CockpitLocator?
final
parameters Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotRequest CockpitScreenshotRequest?
final
snapshotOptions CockpitSnapshotOptions?
final
timeoutMs int?
final

Methods

copyWith({String? commandId, CockpitCommandType? commandType, CockpitLocator? locator, Map<String, Object?>? parameters, CockpitCapturePolicy? capturePolicy, CockpitCaptureFailurePolicy? captureFailurePolicy, int? timeoutMs, CockpitSnapshotOptions? snapshotOptions, CockpitScreenshotRequest? screenshotRequest}) CockpitCommand
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override