CockpitCommandError class final

Constructors

CockpitCommandError({required String code, required String message, Map<String, Object?> details = const <String, Object?>{}})
CockpitCommandError.ambiguousTarget({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.assertionFailed({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.captureFailed({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.fromJson(Map<String, Object?> json)
factory
CockpitCommandError.gestureExecutionFailed({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.invalidGestureParameters({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.targetNotFound({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.targetNotHittable({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.timeout({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory
CockpitCommandError.unsupportedCapability({required String message, Map<String, Object?> details = const <String, Object?>{}})
factory

Properties

code String
final
details Map<String, Object?>
final
hashCode int
The hash code for this object.
no setteroverride
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override