CockpitCommandExecution class final
Constructors
-
CockpitCommandExecution({required CockpitCommandResult result, Map<
String, List< artifactPayloads = const <String, List<int>>{}, Map<int> >String, String> artifactSourcePaths = const <String, String>{}, List<CockpitStepRecord> runtimeSteps = const <CockpitStepRecord>[]})
Properties
-
artifactPayloads
→ Map<
String, List< int> > -
final
-
artifactSourcePaths
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- result → CockpitCommandResult
-
final
-
runtimeSteps
→ List<
CockpitStepRecord> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override