CockpitDocumentResource class final
Constructors
-
CockpitDocumentResource({required String documentId, required String workspaceId, required String relativePath, required String sha256, required DateTime modifiedAt, required CockpitIndexedDocumentKind kind, String? authoredId, String? title, Iterable<
CockpitCaseIndexEntry> cases = const <CockpitCaseIndexEntry>[]}) - Creates a CockpitDocumentResource.
- CockpitDocumentResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
-
Decodes a CockpitDocumentResource from a JSON object.
factory
Properties
-
final
-
cases
→ List<
CockpitCaseIndexEntry> -
final
- documentId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → CockpitIndexedDocumentKind
-
final
- modifiedAt → DateTime
-
final
- relativePath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
final
- title → String?
-
final
- workspaceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitDocumentResource as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited