CockpitEnumValue<T extends Enum> class
final
Constructors
- CockpitEnumValue.known(T value)
-
Creates a CockpitEnumValue using the named constructor
known.factory -
CockpitEnumValue.parse(Object? value, List<
T> values, String path, {required CockpitDecodePolicy policy, bool extensibleResponse = false}) -
Creates a CockpitEnumValue using the named constructor
parse.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isKnown → bool
-
no setter
- knownValue → T?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireValue → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requireKnown(
) → T -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited