CockpitEventCursor class final
Constructors
- CockpitEventCursor({int afterSequence = 0, String? lastEventId})
- Creates a CockpitEventCursor.
- CockpitEventCursor.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitEventCursor from a JSON object.
factory
Properties
- afterSequence → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastEventId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitEventCursor as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited