CockpitEvidenceIndex class final
Constructors
-
CockpitEvidenceIndex.fromSteps(List<
CockpitStepRecord> steps) -
Creates a CockpitEvidenceIndex using the named constructor
fromSteps.factory
Properties
-
artifactRefs
→ List<
CockpitArtifactRef> -
final
- deliveryArtifactsReady → bool
-
final
- deliveryVideoReady → bool
-
final
- failureCount → int
-
final
- flutterScreenshotCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeRecordingCount → int
-
final
- nativeScreenshotCount → int
-
final
- primaryRecordingRef → String
-
final
- primaryScreenshotRef → String
-
final
- recordingCount → int
-
final
-
recordingRefs
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenshotCount → int
-
final
-
screenshotRefs
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited