CockpitEvidencePolicy class final

Constructors

CockpitEvidencePolicy({bool captureBeforeAction = false, bool captureAfterAction = false, bool captureOnFailure = true, bool attachArtifactMetadataOnly = false, bool escalateToDiagnosticsOnAmbiguity = false})
const
CockpitEvidencePolicy.fromJson(Map<String, Object?> json)
factory

Properties

attachArtifactMetadataOnly bool
final
captureAfterAction bool
final
captureBeforeAction bool
final
captureOnFailure bool
final
escalateToDiagnosticsOnAmbiguity bool
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override