CockpitFocusSnapshot class final

Constructors

CockpitFocusSnapshot({required bool hasPrimaryFocus, String? primaryFocusDebugLabel, String? primaryFocusWidgetType, String? primaryFocusElementType, String? primaryFocusLabel, bool isTextInputFocus = false})
Creates a CockpitFocusSnapshot.
const
CockpitFocusSnapshot.fromJson(Map<String, Object?> json)
Decodes a CockpitFocusSnapshot from a JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
hasPrimaryFocus bool
final
isTextInputFocus bool
final
primaryFocusDebugLabel String?
final
primaryFocusElementType String?
final
primaryFocusLabel String?
final
primaryFocusWidgetType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitFocusSnapshot as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override