CockpitGcProfile class final
Aggregate garbage-collection pauses observed in the retained VM timeline.
Durations are derived only from real GC timeline events. A missing profile means the timeline did not expose a verifiable GC event, never that the app had a zero-cost collection cycle.
Constructors
- CockpitGcProfile({required int eventCount, required int timedCount, required int newCount, required int oldCount, required int totalPauseUs, required int p50PauseUs, required int p90PauseUs, required int maxPauseUs, required int newPauseUs, required int oldPauseUs})
-
const
- CockpitGcProfile.fromJson(Object? value)
-
factory
Properties
- eventCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
no setter
- maxPauseUs → int
-
final
- newCount → int
-
final
- newPauseUs → int
-
final
- oldCount → int
-
final
- oldPauseUs → int
-
final
- p50PauseUs → int
-
final
- p90PauseUs → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timedCount → int
-
final
- totalPauseUs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited