CockpitGpuProfile class final
Constructors
- CockpitGpuProfile({required String source, required int events, required int shaderEvents, required int durationUs})
-
const
- CockpitGpuProfile.fromJson(Object? value)
-
factory
Properties
- durationUs → int
-
final
- events → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shaderEvents → int
-
final
- source → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited