CockpitLeaseRequest class final
Constructors
- CockpitLeaseRequest({required String workspaceId, required CockpitLeaseResourceKind resourceKind, required String resourceId, required String holderId, required CockpitIdempotencyKey idempotencyKey, int waitTimeoutMs = 30000, int ttlMs = 30000})
- Creates a CockpitLeaseRequest.
- CockpitLeaseRequest.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitLeaseRequest from a JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- holderId → String
-
final
- idempotencyKey → CockpitIdempotencyKey
-
final
- resourceId → String
-
final
- resourceKind → CockpitLeaseResourceKind
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttlMs → int
-
final
- waitTimeoutMs → int
-
final
- workspaceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitLeaseRequest as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited