CockpitLeaseResource class final

Constructors

CockpitLeaseResource({required String leaseId, required String workspaceId, required CockpitLeaseResourceKind resourceKind, required String resourceId, required String holderId, required CockpitLeaseState state, required DateTime requestedAt, DateTime? acquiredAt, DateTime? expiresAt, DateTime? releasedAt, int? queuePosition, CockpitFailure? failure})
Creates a CockpitLeaseResource.
CockpitLeaseResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitLeaseResource from a JSON object.
factory

Properties

acquiredAt DateTime?
final
expiresAt DateTime?
final
failure CockpitFailure?
final
hashCode int
The hash code for this object.
no setterinherited
holderId String
final
leaseId String
final
queuePosition int?
final
releasedAt DateTime?
final
requestedAt DateTime
final
resourceId String
final
resourceKind CockpitLeaseResourceKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CockpitLeaseState
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitLeaseResource as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited