CockpitLocator class final
Constructors
-
CockpitLocator({String? cockpitId, String? semanticId, String? key, String? text, String? tooltip, String? type, String? route, String? registrationId, String? path, CockpitTextMatchMode matchMode = CockpitTextMatchMode.exact, int? index, CockpitLocator? ancestor, List<
CockpitLocator> fallbacks = const []}) -
Creates a CockpitLocator.
const
-
CockpitLocator.fromJson(Map<
String, Object?> json) -
Decodes a CockpitLocator from a JSON object.
factory
Properties
- ancestor → CockpitLocator?
-
final
- cockpitId → String?
-
final
-
fallbacks
→ List<
CockpitLocator> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasSignals → bool
-
no setter
- index → int?
-
final
- key → String?
-
final
- kind → CockpitLocatorKind
-
no setter
- matchMode → CockpitTextMatchMode
-
final
- path → String?
-
final
- primarySignal → CockpitLocatorSignal?
-
no setter
- registrationId → String?
-
final
- route → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticId → String?
-
final
-
signalMap
→ Map<
String, String> -
no setter
-
signals
→ Iterable<
CockpitLocatorSignal> -
no setter
- text → String?
-
final
- tooltip → String?
-
final
- type → String?
-
final
- value → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitLocator as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override