CockpitNetworkEndpointSummary class final

Constructors

CockpitNetworkEndpointSummary({required String method, required String uriPattern, required int requestCount, required int failureCount, required int averageDurationMs, int? lastStatusCode, String? latestUri})
const
CockpitNetworkEndpointSummary.fromJson(Map<String, Object?> json)
factory

Properties

averageDurationMs int
final
failureCount int
final
hashCode int
The hash code for this object.
no setteroverride
lastStatusCode int?
final
latestUri String?
final
method String
final
requestCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uriPattern String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override