CockpitNetworkRedactor class final
Constructors
- CockpitNetworkRedactor()
-
Creates a CockpitNetworkRedactor.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
body(
String value, {String? contentType}) → String -
contentType(
Map< String, String> headers) → String? -
headers(
Map< Object?, Object?> values) → Map<String, String> -
headerValue(
String name, String value) → String -
isSensitiveName(
String name) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
text(
String value) → String -
toString(
) → String -
A string representation of this object.
inherited
-
uri(
Uri value) → Uri
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited