CockpitNetworkSnapshot class final
Constructors
-
CockpitNetworkSnapshot({required int totalEntryCount, required int failureCount, required List<
CockpitNetworkEntry> entries, List<CockpitNetworkEndpointSummary> endpointSummaries = const <CockpitNetworkEndpointSummary>[], int capturedEntryCount = 0, int inFlightCount = 0, CockpitNetworkQuery query = const CockpitNetworkQuery(), bool truncated = false}) -
const
-
CockpitNetworkSnapshot.fromJson(Map<
String, Object?> json) -
factory
Properties
- capturedEntryCount → int
-
final
-
endpointSummaries
→ List<
CockpitNetworkEndpointSummary> -
final
-
entries
→ List<
CockpitNetworkEntry> -
final
- failureCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inFlightCount → int
-
final
- query → CockpitNetworkQuery
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalEntryCount → int
-
final
- truncated → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override