CockpitOperationCatalog class final
Constructors
-
CockpitOperationCatalog(Iterable<
CockpitOperationContract< contracts)Object?> > - Creates a CockpitOperationCatalog.
Properties
-
descriptors
→ List<
CockpitOperationDescriptor> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
admit(
CockpitOperationInvocation invocation, {required Iterable< String> negotiatedFeatureIds}) → CockpitOperationDescriptor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited