CockpitOperationInvocation class final
Constructors
-
CockpitOperationInvocation({required String kind, Map<
String, Object?> input = const <String, Object?>{}, String? rootId, String? workspaceId, CockpitIdempotencyKey? idempotencyKey, DateTime? deadline, Iterable<String> requiredFeatures = const <String>[]}) - Creates a CockpitOperationInvocation.
- CockpitOperationInvocation.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitOperationInvocation from a JSON object.
factory
Properties
- deadline → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotencyKey → CockpitIdempotencyKey?
-
final
-
input
→ Map<
String, Object?> -
final
- kind → String
-
final
-
requiredFeatures
→ List<
String> -
final
- rootId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workspaceId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitOperationInvocation as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited