CockpitOperationResult class final

Constructors

CockpitOperationResult({required String operationId, required String kind, required CockpitOperationLifecycle lifecycle, required DateTime submittedAt, String? rootId, String? workspaceId, CockpitOperationOutcome? outcome, DateTime? startedAt, DateTime? finishedAt, Map<String, Object?>? output, CockpitFailure? failure})
Creates a CockpitOperationResult.
CockpitOperationResult.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitOperationResult from a JSON object.
factory

Properties

failure CockpitFailure?
final
finishedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
kind String
final
lifecycle CockpitOperationLifecycle
final
operationId String
final
outcome CockpitOperationOutcome?
final
output Map<String, Object?>?
final
rootId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime?
final
submittedAt DateTime
final
workspaceId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitOperationResult as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited