CockpitPerformanceMemoryReport class final
Bounded process-memory timeline captured alongside frame timings.
Constructors
-
CockpitPerformanceMemoryReport({String source = 'process', required int intervalMs, required Iterable<
CockpitPerformanceMemorySample> samples, int droppedSamples = 0}) -
factory
- CockpitPerformanceMemoryReport.fromJson(Object? value)
-
factory
Properties
- droppedSamples → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- intervalMs → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
samples
→ List<
CockpitPerformanceMemorySample> -
final
- source → String
-
final
- summary → CockpitPerformanceMemorySummary
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override