CockpitPerformanceMemorySummary class final
Aggregate memory pressure for the retained samples in one capture.
Constructors
- CockpitPerformanceMemorySummary({required int sampleCount, required int startRssBytes, required int endRssBytes, required int minRssBytes, required int maxRssBytes, required int averageRssBytes, required int processPeakBytes, required int deltaRssBytes})
-
const
- CockpitPerformanceMemorySummary.fromJson(Object? value)
-
factory
Properties
- averageRssBytes → int
-
final
- deltaRssBytes → int
-
final
- endRssBytes → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isValid → bool
-
no setter
- maxRssBytes → int
-
final
- minRssBytes → int
-
final
- processPeakBytes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleCount → int
-
final
- startRssBytes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override