CockpitPerformancePluginRun class abstract
State and lifecycle owner for one performance capture.
A Run is created for one capture only. Override start to install hooks and stop to remove them and publish final state. stop is called even when start fails, subject to the plugin lifecycle timeout.
Constructors
- CockpitPerformancePluginRun()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → FutureOr< void> -
stop(
CockpitPerformancePluginStats stats) → FutureOr< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited