CockpitPerformanceSpan class final
A completed or in-progress span returned by CockpitPerformanceSink.begin.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
end(
{Map< String, Object?> args = const <String, Object?>{}}) → void - Ends the span once. Repeated calls are safe no-ops.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited