CockpitRebuildEntry class final
Constructors
Properties
- builtOnceCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- keyValue → String?
-
final
- rebuildCount → int
-
final
- routeName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticId → String?
-
final
- signature → String
-
final
- textPreview → String?
-
final
- typeName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override