CockpitRebuildSnapshot class final
Constructors
-
CockpitRebuildSnapshot({required int totalRebuildCount, required int uniqueElementCount, required int capturedEntryCount, required bool truncated, required List<
CockpitRebuildEntry> entries}) -
const
-
CockpitRebuildSnapshot.fromJson(Map<
String, Object?> json) -
factory
Properties
- capturedEntryCount → int
-
final
-
entries
→ List<
CockpitRebuildEntry> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalRebuildCount → int
-
final
- truncated → bool
-
final
- uniqueElementCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override