CockpitRemoteCommandResponse class final

Constructors

CockpitRemoteCommandResponse({required CockpitCommandResult result, List<CockpitRemoteArtifactPayload> artifactPayloads = const <CockpitRemoteArtifactPayload>[], List<CockpitStepRecord> runtimeSteps = const <CockpitStepRecord>[], List<CockpitRemoteArtifactDownload> artifactDownloads = const <CockpitRemoteArtifactDownload>[]})
CockpitRemoteCommandResponse.fromExecution(CockpitCommandExecution execution)
factory
CockpitRemoteCommandResponse.fromJson(Map<String, Object?> json)
factory

Properties

artifactDownloads List<CockpitRemoteArtifactDownload>
final
artifactPayloads List<CockpitRemoteArtifactPayload>
final
hashCode int
The hash code for this object.
no setteroverride
result CockpitCommandResult
final
runtimeSteps List<CockpitStepRecord>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toExecution() CockpitCommandExecution
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override