CockpitRemoteRecordingResponse class final

Constructors

CockpitRemoteRecordingResponse({required CockpitRecordingResult result, List<CockpitRemoteArtifactDownload> artifactDownloads = const <CockpitRemoteArtifactDownload>[]})
CockpitRemoteRecordingResponse.fromJson(Map<String, Object?> json)
factory

Properties

artifactDownloads List<CockpitRemoteArtifactDownload>
final
hashCode int
The hash code for this object.
no setteroverride
result CockpitRecordingResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override