CockpitRemoteSessionConfiguration class final
Constructors
- CockpitRemoteSessionConfiguration({required bool enabled, bool autoStart = true, String host = '127.0.0.1', int port = 47331, String routePrefix = '', String launchId = ''})
-
Creates a CockpitRemoteSessionConfiguration.
const
-
CockpitRemoteSessionConfiguration.fromJson(Map<
String, Object?> json) -
Decodes a CockpitRemoteSessionConfiguration from a JSON object.
factory
Properties
- autoStart → bool
-
final
- baseUri → Uri
-
no setter
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- host → String
-
final
- launchId → String
-
final
- normalizedRoutePrefix → String
-
no setter
- port → int
-
final
- routePrefix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRemoteSessionConfiguration as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
resolve(
{CockpitRemoteSessionConfiguration? fallback, Map< String, String> defines = const <String, String>{}}) → CockpitRemoteSessionConfiguration? -
resolveFromEnvironment(
{CockpitRemoteSessionConfiguration? fallback}) → CockpitRemoteSessionConfiguration?