CockpitRemoteSnapshotResponse class final

Constructors

CockpitRemoteSnapshotResponse({required CockpitSnapshot snapshot, List<CockpitRemoteArtifactDownload> artifactDownloads = const <CockpitRemoteArtifactDownload>[]})
Creates a CockpitRemoteSnapshotResponse.
CockpitRemoteSnapshotResponse.fromJson(Map<String, Object?> json)
Decodes a CockpitRemoteSnapshotResponse from a JSON object.
factory

Properties

artifactDownloads List<CockpitRemoteArtifactDownload>
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot CockpitSnapshot
final

Methods

copyWith({CockpitSnapshot? snapshot, List<CockpitRemoteArtifactDownload>? artifactDownloads}) CockpitRemoteSnapshotResponse
Returns a copy of this CockpitRemoteSnapshotResponse with supplied fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitRemoteSnapshotResponse as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override