CockpitRunCancellation class final
Constructors
- CockpitRunCancellation({required String runId, required DateTime requestedAt, required bool replayed})
- Creates a CockpitRunCancellation.
- CockpitRunCancellation.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
-
Decodes a CockpitRunCancellation from a JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- replayed → bool
-
final
- requestedAt → DateTime
-
final
- runId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRunCancellation as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited