CockpitRunCaseResource class final
Constructors
-
CockpitRunCaseResource({required String runId, required String caseId, required String sourceSha256, required Iterable<
String> attemptIds, CockpitRunOutcome? outcome, CockpitRunStability? stability}) - Creates a CockpitRunCaseResource.
- CockpitRunCaseResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
-
Decodes a CockpitRunCaseResource from a JSON object.
factory
Properties
-
attemptIds
→ List<
String> -
final
- caseId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outcome → CockpitRunOutcome?
-
final
- runId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceSha256 → String
-
final
- stability → CockpitRunStability?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRunCaseResource as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited