CockpitRunSubmission class final
Constructors
-
CockpitRunSubmission({required String workspaceId, required CockpitRunSubmissionSource source, required CockpitIdempotencyKey idempotencyKey, Map<
String, Object?> inputs = const <String, Object?>{}, String? targetId, int? timeoutMs, Iterable<String> requiredFeatures = const <String>[]}) - Creates a CockpitRunSubmission.
- CockpitRunSubmission.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitRunSubmission from a JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotencyKey → CockpitIdempotencyKey
-
final
-
inputs
→ Map<
String, Object?> -
final
-
requiredFeatures
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → CockpitRunSubmissionSource
-
final
- targetId → String?
-
final
- timeoutMs → int?
-
final
- workspaceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRunSubmission as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited