CockpitRuntimeEvent class final
Constructors
-
CockpitRuntimeEvent({required String eventId, required CockpitRuntimeEventKind kind, required CockpitRuntimeEventSeverity severity, required String message, required DateTime recordedAt, String? routeName, String? source, Map<
String, String> details = const <String, String>{}, String? stackTracePreview, bool stackTraceTruncated = false}) -
Creates a CockpitRuntimeEvent.
const
-
CockpitRuntimeEvent.fromJson(Map<
String, Object?> json) -
Decodes a CockpitRuntimeEvent from a JSON object.
factory
Properties
-
details
→ Map<
String, String> -
final
- eventId → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isError → bool
-
no setter
- isWarning → bool
-
no setter
- kind → CockpitRuntimeEventKind
-
final
- message → String
-
final
- recordedAt → DateTime
-
final
- routeName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → CockpitRuntimeEventSeverity
-
final
- source → String?
-
final
- stackTracePreview → String?
-
final
- stackTraceTruncated → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitRuntimeEvent as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override