CockpitScreenshotRequest class final
Constructors
- CockpitScreenshotRequest({required CockpitScreenshotReason reason, required String name, bool includeSnapshot = false, bool attachToStep = false, CockpitSnapshotOptions? snapshotOptions, CockpitCaptureProfile? profile, bool? allowFallback, CockpitLocator? cropLocator})
-
Creates a CockpitScreenshotRequest.
const
-
CockpitScreenshotRequest.fromJson(Map<
String, Object?> json) -
Decodes a CockpitScreenshotRequest from a JSON object.
factory
Properties
- allowFallback → bool?
-
final
- allowsFallback → bool
-
no setter
- attachToStep → bool
-
final
- cropLocator → CockpitLocator?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- includeSnapshot → bool
-
final
- name → String
-
final
- profile → CockpitCaptureProfile?
-
final
- reason → CockpitScreenshotReason
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotOptions → CockpitSnapshotOptions?
-
final
Methods
-
copyWith(
{CockpitScreenshotReason? reason, String? name, bool? includeSnapshot, bool? attachToStep, CockpitSnapshotOptions? snapshotOptions, Object? profile = _unsetField, Object? allowFallback = _unsetField, Object? cropLocator = _unsetField}) → CockpitScreenshotRequest - Returns a copy of this CockpitScreenshotRequest with supplied fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitScreenshotRequest as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override