CockpitSnapshotLayout class final
Constructors
- CockpitSnapshotLayout({required double width, required double height, required double dx, required double dy, String? constraintsSummary})
-
Creates a CockpitSnapshotLayout.
const
-
CockpitSnapshotLayout.fromJson(Map<
String, Object?> json) -
Decodes a CockpitSnapshotLayout from a JSON object.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitSnapshotLayout as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override