CockpitTestArtifactEntry class final
Constructors
Properties
- artifactId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- mediaType → String
-
final
- relativePath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
final
- sizeBytes → int
-
final
- stepExecutionId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited