CockpitTestAttemptBundleManifest class final
Constructors
-
CockpitTestAttemptBundleManifest({String schemaVersion = 'cockpit.report/v2', required CockpitTestRunContext context, required String sourceSha256, required DateTime createdAt, required CockpitTestAttemptResult result, Iterable<
CockpitTestArtifactEntry> artifacts = const <CockpitTestArtifactEntry>[], Iterable<CockpitTestEvidenceIndexEntry> evidenceIndex = const <CockpitTestEvidenceIndexEntry>[]}) - Creates a CockpitTestAttemptBundleManifest.
- CockpitTestAttemptBundleManifest.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestAttemptBundleManifest from a JSON object.
factory
Properties
-
artifacts
→ List<
CockpitTestArtifactEntry> -
final
- context → CockpitTestRunContext
-
final
- createdAt → DateTime
-
final
-
evidenceIndex
→ List<
CockpitTestEvidenceIndexEntry> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → CockpitTestAttemptResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
final
- sourceSha256 → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestAttemptBundleManifest as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited