CockpitTestCaseDefaults class final
Constructors
- CockpitTestCaseDefaults({int commandTimeoutMs = 10000, int cleanupTimeoutMs = 30000, bool failFast = true, CockpitTestEvidencePolicy evidence = const CockpitTestEvidencePolicy(), CockpitTestCompilerLimits limits = CockpitTestCompilerLimits.standard})
-
Creates a CockpitTestCaseDefaults.
factory
- CockpitTestCaseDefaults.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestCaseDefaults from a JSON object.
factory
Properties
- cleanupTimeoutMs → int
-
final
- commandTimeoutMs → int
-
final
- evidence → CockpitTestEvidencePolicy
-
final
- failFast → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limits → CockpitTestCompilerLimits
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestCaseDefaults as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- standard → const CockpitTestCaseDefaults