CockpitTestCompilerLimits class final
Constructors
- CockpitTestCompilerLimits({int maxDocumentBytes = 1048576, int maxNesting = 16, int maxExpandedSteps = 10000, int maxLoopIterations = 1000, int maxRetryAttempts = 20})
-
Creates a CockpitTestCompilerLimits.
factory
- CockpitTestCompilerLimits.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestCompilerLimits from a JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDocumentBytes → int
-
final
- maxExpandedSteps → int
-
final
- maxLoopIterations → int
-
final
- maxNesting → int
-
final
- maxRetryAttempts → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestCompilerLimits as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- standard → const CockpitTestCompilerLimits