CockpitTestConditionEvaluation class final
Constructors
- CockpitTestConditionEvaluation.error(CockpitTestError error)
-
Creates a CockpitTestConditionEvaluation using the named constructor
error.const - CockpitTestConditionEvaluation.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestConditionEvaluation from a JSON object.
factory
- CockpitTestConditionEvaluation.matched()
-
Creates a CockpitTestConditionEvaluation using the named constructor
matched.const - CockpitTestConditionEvaluation.notMatched()
-
Creates a CockpitTestConditionEvaluation using the named constructor
notMatched.const
Properties
- error → CockpitTestError?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → CockpitTestConditionState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestConditionEvaluation as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited