CockpitTestDiagnostic class final
Constructors
-
CockpitTestDiagnostic({required String code, required String message, required String path, CockpitTestDiagnosticSeverity severity = CockpitTestDiagnosticSeverity.error, CockpitTestSourceLocation? location, Map<
String, Object?> details = const <String, Object?>{}}) - Creates a CockpitTestDiagnostic.
- CockpitTestDiagnostic.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestDiagnostic from a JSON object.
factory
Properties
- code → String
-
final
-
details
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → CockpitTestSourceLocation?
-
final
- message → String
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → CockpitTestDiagnosticSeverity
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestDiagnostic as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited