CockpitTestError class final
Constructors
-
CockpitTestError({required CockpitTestErrorCode code, required String message, String? path, String? stepId, CockpitTestSourceLocation? location, Map<
String, Object?> details = const <String, Object?>{}}) - CockpitTestError.fromJson(Object? value, {String path = r'$'})
-
factory
Properties
- code → CockpitTestErrorCode
-
final
-
details
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → CockpitTestSourceLocation?
-
final
- message → String
-
final
- path → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited