CockpitTestImportManifest class final
Constructors
-
CockpitTestImportManifest({String schemaVersion = 'cockpit.import/v2', required int sourceVersion, required String sourceSha256, required String projectId, required String workspaceId, required String caseId, required String engineVersion, Iterable<
CockpitTestImportMapping> mappings = const <CockpitTestImportMapping>[], Iterable<String> warnings = const <String>[]}) - Creates a CockpitTestImportManifest.
- CockpitTestImportManifest.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestImportManifest from a JSON object.
factory
Properties
- caseId → String
-
final
- engineVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mappings
→ List<
CockpitTestImportMapping> -
final
- projectId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → String
-
final
- sourceSha256 → String
-
final
- sourceVersion → int
-
final
-
warnings
→ List<
String> -
final
- workspaceId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestImportManifest as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited