CockpitTestProjectTarget class final
Constructors
-
CockpitTestProjectTarget({required CockpitTestTargetRequirements requirements, Iterable<
String> deviceIds = const <String>[], Map<String, String> labels = const <String, String>{}}) - Creates a CockpitTestProjectTarget.
- CockpitTestProjectTarget.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestProjectTarget from a JSON object.
factory
Properties
-
deviceIds
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
→ Map<
String, String> -
final
- requirements → CockpitTestTargetRequirements
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestProjectTarget as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited