CockpitTestReportArtifact class final
Constructors
- CockpitTestReportArtifact({required String evidenceId, required String resourceId, required String attemptId, String? stepExecutionId, required String kind, required String relativePath, required String mediaType, required int sizeBytes, required String sha256, required DateTime createdAt})
- Creates a CockpitTestReportArtifact.
- CockpitTestReportArtifact.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestReportArtifact from a JSON object.
factory
Properties
- attemptId → String
-
final
- createdAt → DateTime
-
final
- evidenceId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- mediaType → String
-
final
- relativePath → String
-
final
- resourceId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
final
- sizeBytes → int
-
final
- stepExecutionId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestReportArtifact as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited