CockpitTestReportBundleFile class final
Constructors
- CockpitTestReportBundleFile({required String relativePath, required String kind, required String mediaType, required int sizeBytes, required String sha256, required String runId, String? caseId, String? attemptId, String? stepExecutionId, String? resourceId, String? evidenceId})
- Creates a CockpitTestReportBundleFile.
- CockpitTestReportBundleFile.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestReportBundleFile from a JSON object.
factory
Properties
- attemptId → String?
-
final
- caseId → String?
-
final
- evidenceId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- mediaType → String
-
final
- relativePath → String
-
final
- resourceId → String?
-
final
- runId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sha256 → String
-
final
- sizeBytes → int
-
final
- stepExecutionId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestReportBundleFile as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited