CockpitTestReportExecution class final
Constructors
-
CockpitTestReportExecution({required CockpitTestReportExecutionRole role, String? entryId, int? attemptNumber, required CockpitTestAttemptResult result, Iterable<
CockpitTestReportArtifact> artifacts = const <CockpitTestReportArtifact>[]}) - Creates a CockpitTestReportExecution.
- CockpitTestReportExecution.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestReportExecution from a JSON object.
factory
Properties
-
artifacts
→ List<
CockpitTestReportArtifact> -
final
- attemptNumber → int?
-
final
- entryId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → CockpitTestAttemptResult
-
final
- role → CockpitTestReportExecutionRole
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestReportExecution as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited