CockpitTestStartRecordingOperationTemplate class final
- Inheritance
-
- Object
- CockpitTestOperationTemplate
- CockpitTestStartRecordingOperationTemplate
Constructors
- CockpitTestStartRecordingOperationTemplate({required String name, String purpose = 'acceptance', String mode = 'auto', String? layer, bool? allowFallback, bool attachToStep = true})
- CockpitTestStartRecordingOperationTemplate.fromJson(Object? value, {required String path})
-
factory
Properties
- allowFallback → bool?
-
final
- attachToStep → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layer → String?
-
final
- mode → String
-
final
- name → String
-
final
- purpose → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireName → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited