CockpitTestStepResult class final
Constructors
-
CockpitTestStepResult({required String stepId, required String executionId, required String section, String? description, String? operation, int? timeoutMs, String? definitionPath, required CockpitTestStepStatus status, required DateTime startedAt, required int durationMs, CockpitTestStepOccurrence? occurrence, CockpitTestSourceLocation? sourceLocation, CockpitTestPlane? requestedPlane, CockpitTestPlane? actualPlane, String? driverId, CockpitLocatorResolution? locatorResolution, String? degradationReason, CockpitTestError? error, Iterable<
String> evidence = const <String>[]}) - Creates a CockpitTestStepResult.
- CockpitTestStepResult.fromJson(Object? value, {String path = r'$'})
-
Decodes a CockpitTestStepResult from a JSON object.
factory
Properties
- actualPlane → CockpitTestPlane?
-
final
- definitionPath → String?
-
final
- degradationReason → String?
-
final
- description → String?
-
final
- driverId → String?
-
final
- durationMs → int
-
final
- error → CockpitTestError?
-
final
-
evidence
→ List<
String> -
final
- executionId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- locatorResolution → CockpitLocatorResolution?
-
final
- occurrence → CockpitTestStepOccurrence
-
final
- operation → String?
-
final
- requestedPlane → CockpitTestPlane?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- section → String
-
final
- sourceLocation → CockpitTestSourceLocation?
-
final
- startedAt → DateTime
-
final
- status → CockpitTestStepStatus
-
final
- stepId → String
-
final
- timeoutMs → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestStepResult as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited