CockpitTestStepTemplate class final
Constructors
-
CockpitTestStepTemplate({required String stepId, String? description, CockpitTestPlane? plane, int? timeoutMs, CockpitTestEvidencePolicy? evidence, CockpitTestSafetyDeclaration? safety, required CockpitTestOperationTemplate operation, Map<
String, Object?> extensions = const <String, Object?>{}}) - Creates a CockpitTestStepTemplate.
- CockpitTestStepTemplate.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestStepTemplate from a JSON object.
factory
Properties
- description → String?
-
final
- evidence → CockpitTestEvidencePolicy?
-
final
-
extensions
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operation → CockpitTestOperationTemplate
-
final
- plane → CockpitTestPlane?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safety → CockpitTestSafetyDeclaration?
-
final
- stepId → String
-
final
- timeoutMs → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestStepTemplate as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited