CockpitTestSuiteEntry class final
Constructors
-
CockpitTestSuiteEntry({required String id, required CockpitTestSuiteCaseSource source, Iterable<
String> dependsOn = const <String>[], Iterable<String> fixtures = const <String>[], Iterable<String> matrixAxes = const <String>[], Iterable<String> targetIds = const <String>[], Map<String, Object?> inputs = const <String, Object?>{}, CockpitTestSuiteRetryPolicy? retry, Iterable<String> tags = const <String>[]}) - Creates a CockpitTestSuiteEntry.
- CockpitTestSuiteEntry.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestSuiteEntry from a JSON object.
factory
Properties
-
dependsOn
→ List<
String> -
final
-
fixtures
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
inputs
→ Map<
String, Object?> -
final
-
matrixAxes
→ List<
String> -
final
- retry → CockpitTestSuiteRetryPolicy?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → CockpitTestSuiteCaseSource
-
final
-
final
-
targetIds
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestSuiteEntry as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited