CockpitTestSuiteRetryPolicy class final
Constructors
-
CockpitTestSuiteRetryPolicy({int maxAttempts = 1, int delayMs = 0, Iterable<
CockpitTestSuiteRetryReason> retryOn = const <CockpitTestSuiteRetryReason>[CockpitTestSuiteRetryReason.blocked, CockpitTestSuiteRetryReason.interrupted, CockpitTestSuiteRetryReason.internalError]}) - Creates a CockpitTestSuiteRetryPolicy.
- CockpitTestSuiteRetryPolicy.fromJson(Object? value, {required String path})
-
Decodes a CockpitTestSuiteRetryPolicy from a JSON object.
factory
Properties
- delayMs → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAttempts → int
-
final
-
retryOn
→ Set<
CockpitTestSuiteRetryReason> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitTestSuiteRetryPolicy as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- standard → CockpitTestSuiteRetryPolicy
-
final