CockpitTextInputRequest class final

Constructors

CockpitTextInputRequest({String? text, int? selectionBase, int? selectionExtent, CockpitTextInputAction? inputAction, bool requestFocus = true, bool clearExisting = false})
const
CockpitTextInputRequest.fromJson(Map<String, Object?> json)
factory

Properties

clearExisting bool
final
hasEditingMutation bool
no setter
hashCode int
The hash code for this object.
no setteroverride
inputAction CockpitTextInputAction?
final
requestFocus bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionBase int?
final
selectionExtent int?
final
text String?
final

Methods

copyWith({String? text, int? selectionBase, int? selectionExtent, CockpitTextInputAction? inputAction, bool? requestFocus, bool? clearExisting, bool clearText = false, bool clearSelectionBase = false, bool clearSelectionExtent = false, bool clearInputAction = false}) CockpitTextInputRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override