CockpitTimelineProfile class final
Timeline recorder and stream capabilities observed from VM Service.
Constructors
-
CockpitTimelineProfile({required String recorder, required Iterable<
String> availableStreams, required Iterable<String> recordedStreams}) - CockpitTimelineProfile.fromJson(Object? value)
-
factory
Properties
-
availableStreams
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
recordedStreams
→ List<
String> -
final
- recorder → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited