CockpitViewportResizeResult class final
Constructors
-
CockpitViewportResizeResult({required bool available, required bool changed, required int requestedWidth, required int requestedHeight, required String platform, double? logicalWidth, double? logicalHeight, int? physicalWidth, int? physicalHeight, double? devicePixelRatio, String? reason, List<
String> alternatives = const <String>[]}) - Creates a CockpitViewportResizeResult.
-
CockpitViewportResizeResult.fromJson(Map<
String, Object?> json) -
Decodes a CockpitViewportResizeResult from a JSON object.
factory
Properties
-
alternatives
→ List<
String> -
final
- available → bool
-
final
- changed → bool
-
final
- devicePixelRatio → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logicalHeight → double?
-
final
- logicalWidth → double?
-
final
- physicalHeight → int?
-
final
- physicalWidth → int?
-
final
- platform → String
-
final
- reason → String?
-
final
- requestedHeight → int
-
final
- requestedWidth → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitViewportResizeResult as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited