CockpitVmMemoryNode class final
One bounded node from VM Service process-memory accounting.
Constructors
-
CockpitVmMemoryNode({required String name, required int sizeBytes, Iterable<
CockpitVmMemoryNode> children = const <CockpitVmMemoryNode>[], int droppedChildren = 0}) - CockpitVmMemoryNode.fromJson(Object? value)
-
factory
Properties
-
children
→ List<
CockpitVmMemoryNode> -
final
- droppedChildren → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDepth → int
-
no setter
- name → String
-
final
- nodeCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited