CockpitWebSocketFrame class final
Constructors
- CockpitWebSocketFrame({required int sequence, required CockpitWebSocketDirection direction, required CockpitWebSocketFrameKind kind, required DateTime at, required int payloadBytes, required bool finalFragment, required bool compressed, String? preview})
-
Creates a CockpitWebSocketFrame.
const
-
CockpitWebSocketFrame.fromJson(Map<
String, Object?> json) -
Decodes a CockpitWebSocketFrame from a JSON object.
factory
Properties
- at → DateTime
-
final
- compressed → bool
-
final
- direction → CockpitWebSocketDirection
-
final
- finalFragment → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- kind → CockpitWebSocketFrameKind
-
final
- payloadBytes → int
-
final
- preview → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitWebSocketFrame as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override