CockpitWidgetTree class final
Constructors
-
CockpitWidgetTree({required CockpitWidgetTreeProfile profile, required int total, required int visible, required bool truncated, int? emitted, List<
CockpitWidgetNode> nodes = const <CockpitWidgetNode>[]}) - Creates one bounded mounted Flutter Widget tree projection.
-
CockpitWidgetTree.fromJson(Map<
String, Object?> json) -
Decodes a Widget tree from a JSON object.
factory
Properties
- emitted → int
-
Number of nodes emitted in nodes.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
nodes
→ List<
CockpitWidgetNode> -
Profile-selected mounted Widget nodes.
final
- profile → CockpitWidgetTreeProfile
-
Detail profile used to create this tree.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
Total mounted Element count before profile filtering and truncation.
final
- truncated → bool
-
Whether profile-selected nodes exceeded the emitted node limit.
final
- visible → int
-
Total mounted nodes visible through the root viewport.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this Widget tree as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override