CockpitWidgetTreeOptions class final
Constructors
- CockpitWidgetTreeOptions({CockpitWidgetTreeProfile profile = CockpitWidgetTreeProfile.minimal, int maxNodes = 800, int maxProps = 0})
-
Creates bounded widget-tree capture options.
const
-
CockpitWidgetTreeOptions.fromJson(Map<
String, Object?> json) -
Decodes widget-tree capture options from a JSON object.
factory
- CockpitWidgetTreeOptions.full()
-
Creates the complete mounted Element diagnostics profile.
const
- CockpitWidgetTreeOptions.minimal()
-
Creates the concise actionable/content tree profile.
const
- CockpitWidgetTreeOptions.standard()
-
Creates the mounted public Widget structure profile.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxNodes → int
-
Maximum number of nodes emitted in the response or artifact.
final
- maxProps → int
-
Maximum diagnostic properties emitted per node.
final
- profile → CockpitWidgetTreeProfile
-
Detail profile applied while selecting and projecting nodes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{CockpitWidgetTreeProfile? profile, int? maxNodes, int? maxProps}) → CockpitWidgetTreeOptions - Returns a copy with the supplied fields replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes these options as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override