CockpitDiscoveryEngine class
final
Methods
-
discover({required BuildContext rootContext, required String? routeName, List<CockpitTarget> explicitTargets = const <CockpitTarget>[], bool allowInactiveRouteFallback = false, bool includeClippedTargets = false})
→ List<CockpitTarget>
-
-
discoverRelatedActionTargets({required BuildContext rootContext, required Element element, required String? routeName, required CockpitCommandType requiredCommand, List<CockpitTarget> explicitTargets = const <CockpitTarget>[]})
→ List<CockpitTarget>
-
Discovers actionable targets related to one matched Flutter element.
-
hasDiscoverableTarget({required BuildContext rootContext, required String? routeName, List<CockpitTarget> explicitTargets = const <CockpitTarget>[], bool allowInactiveRouteFallback = false})
→ bool
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited