CockpitDiscoveryEngine class final
Constructors
- CockpitDiscoveryEngine({CockpitDiscoveryPolicy policy = const CockpitDiscoveryPolicy()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy → CockpitDiscoveryPolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
discover(
{required BuildContext rootContext, required String? routeName, List< CockpitTarget> explicitTargets = const <CockpitTarget>[], bool allowInactiveRouteFallback = false}) → List<CockpitTarget> -
hasDiscoverableTarget(
{required BuildContext rootContext, required String? routeName, List< CockpitTarget> explicitTargets = const <CockpitTarget>[], bool allowInactiveRouteFallback = false}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited