Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
bootstrap([FlutterCockpitConfig config = const FlutterCockpitConfig.production()])
→ FlutterCockpitBinding
-
-
clearRecordedSteps()
→ void
-
-
dispose()
→ void
-
-
drainRecordedSteps({bool clear = true})
→ List<CockpitStepRecord>
-
-
ensureInitialized([FlutterCockpitConfig config = const FlutterCockpitConfig.production()])
→ FlutterCockpitBinding
-
-
initialize([FlutterCockpitConfiguration configuration = const FlutterCockpitConfiguration()])
→ FlutterCockpitBinding
-
-
recordStep({required String actionType, required Map<String, Object?> actionArgs, CockpitObservation? observation, CockpitSnapshot? snapshot, List<CockpitArtifactRef> artifactRefs = const [], CockpitCommandType? commandType, CockpitLocator? locator, CockpitLocatorResolution? locatorResolution, int? durationMs, CockpitCommandStatus? status, CockpitCaptureProfile? requestedCaptureProfile, CockpitCaptureKind? resolvedCaptureKind, bool usedCaptureFallback = false, String? degradationReason, List<CockpitArtifactRef> captureRefs = const []})
→ void
-
-
runApp(Widget child, {FlutterCockpitConfig config = const FlutterCockpitConfig.production()})
→ void
-
-
setCurrentRouteName(String routeName)
→ void
-