FlutterCockpitBinding class final
Constructors
- FlutterCockpitBinding(FlutterCockpitConfiguration configuration)
Properties
- activeRecordingSession → CockpitRecordingSession?
-
no setter
- configuration → FlutterCockpitConfiguration
-
no setter
-
currentRouteName
→ ValueNotifier<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeCapture ↔ CockpitNativeCapture
-
getter/setter pair
- nativeRecording ↔ CockpitNativeRecording
-
getter/setter pair
-
latefinal
- networkObserver ↔ CockpitNetworkObserver?
-
getter/setter pair
- rebuildTracker ↔ CockpitRebuildTracker?
-
getter/setter pair
- registry ↔ CockpitTargetRegistry
-
getter/setter pair
- runtimeObserver ↔ CockpitRuntimeObserver?
-
getter/setter pair
- runtimeStepBuffer → CockpitRuntimeStepBuffer
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionController ↔ CockpitSessionController
-
getter/setter pair
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryNativeCaptureAvailability(
) → Future< bool> -
queryRecordingCapabilities(
) → Future< CockpitRecordingCapabilities> -
resolveRuntimeEnvironment(
{required String platform}) → CockpitEnvironment? -
setCurrentRouteName(
String routeName) → void -
startRecording(
CockpitRecordingRequest request) → Future< CockpitRecordingSession> -
stopRecording(
) → Future< CockpitRecordingResult> -
toString(
) → String -
A string representation of this object.
inherited
-
updateConfiguration(
FlutterCockpitConfiguration nextConfiguration) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited